--  Created by zhangchao on 15-05-14.
--[[滚动文字]]
ZCMarqueeNode = class("ZCMarqueeNode", function(params)
    return ZCSprite:create()
end)

ZCMarqueeNode.data = {}

function ZCMarqueeNode:ctor(params)
	--创建默认参数
	ZCMarqueeNode.data = {}
    local defaultParams = {
        text            = "",
        bg 				= "res/Main/common/marquee_bg.png",--[[背景图]]
        fontSize        = 20,--字体大小
        speed           = 100,
        pos             = cc.p(0,0),
        color           = cc.c3b(255, 255, 255),
        anchor          = cc.p(0.5,0.5),--锚点
        needSwallow     = false,--是否需要吞噬事件
        clickable       = true,--是否可以点击
        beganCallback   = nil,--点击事件的按下回调
        endCallback     = nil,--点击事件的抬起回调
        touchSize       = cc.size(0,0),--点击区域，如果没有传值，则默认点击区域为getBoundingBox()
        x               = 0,--x
        y               = 0--y
    }

    if params == nil then params = {} end
    for k, v in pairs(defaultParams) do
        if params[k] == nil then
            params[k] = v
        end
    end
    --[[初始化背景图]]
    local bg 			= params.bg
    local fontSize  	= params.fontSize
    local text 			= params.text
    local pos 			= params.pos
    local anchor 		= params.anchor
    local speed 		= params.speed
    local needSwallow 	= params.needSwallow
    local clickable 	= params.clickable
    local beganCallback = params.beganCallback
    local endCallback 	= params.endCallback

    self:initWithFile(bg)
    local _tip = zc.createSprite("res/Main/common/marquee_tip.png")
    _tip:setPosition(self:getContentSize().width*0.1, self:getContentSize().height*0.5)
    self:addChild(_tip, 1)
    self:setAnchorPoint(anchor)
    self:setPosition(pos)

	self:setSwallowTouches(needSwallow)
    self:setClickable(clickable)

    self:setTouchBeganCallback(beganCallback)
    self:setTouchEndedCallback(endCallback)
	--[[初始化数据]]
	self._data = {}
	--[[默认不可见]]
	self:setVisible(false)
	--[[裁剪区域]]
	self:initClipping()

	--[[设置默认速度]]
	self:setSpeed(speed)

	self:setCascadeOpacityEnabled(true)
	self._isRunning = false

	self:setString(text)
end
--[[设置字体大小，可以保证不改变字体样式]]
function ZCMarqueeNode:setFontSize(fontSize)
    self.__labelNode:setFontSize(fontSize)
end
--[[
@speed  每秒移动的像素
]]
function ZCMarqueeNode:setSpeed(speed)
	self._speed = speed
end

function ZCMarqueeNode:_excute()
	if #ZCMarqueeNode.data > 0 then
		local text = table.remove(ZCMarqueeNode.data,1)
		self:setVisible(true)

		if self.__labelNode then 
			self.__labelNode:removeFromParent()
		end 
		self.__labelNode = zc.createRichLabel({}) 
		self.__labelNode:setFontSize(22)
		self.__labelNode:setFontFillColor(cc.c3b(255, 255, 255))
		self.__labelNode:setHorizontalAlignment(cc.TEXT_ALIGNMENT_LEFT)
		self.__labelNode:setVerticalAlignment(cc.VERTICAL_TEXT_ALIGNMENT_TOP)
		self.__labelNode:setString(text)
		self.__labelNode:setAnchorPoint(0, 0.5)
		self.__labelNode:setPosition(self:getContentSize().width - 20, self:getContentSize().height*0.5 - 1)
		self.__clip:addChild(self.__labelNode)

		local speed = self._speed
		local x,y = self.__labelNode:getPosition()
		local _finalX = self:getContentSize().width*0.1 - self.__labelNode:getContentSize().width - 100
		local len = x - _finalX
		local time = math.abs(len / speed)
		local move = cc.MoveBy:create(time, cc.p(-len, 0))
		local call = cc.CallFunc:create(function( )
			self:_excute()
		end)
		local action = cc.Sequence:create(move,call)
		action:setTag(1)
		self.__labelNode:runAction(action)
	else
		if self.__labelNode then 
			self.__labelNode:removeFromParent()
			self.__labelNode = nil
		end 
		self._isRunning = false
		self:runAction(cc.FadeOut:create(0.2))
	end
end

function ZCMarqueeNode:setString(text)
	if text == nil or string.len(tostring(text)) < 1 then
		return
	end
	self:insertAData(text)
	self:run()
end

function ZCMarqueeNode:run()
	if PlayerData and PlayerData._cardExtracting then
		return
	end
	if self._isRunning == false then 
		self._isRunning = true
		self:runAction(cc.FadeIn:create(0.2))
		self:_excute()
	end 
end

function ZCMarqueeNode:create()
    return ZCMarqueeNode.new()
end

function ZCMarqueeNode:createWithParams(params)
    return ZCMarqueeNode.new(params)
end

function ZCMarqueeNode:setSource( data )
	if data then 
		self:insertAData(data)
		if self._isRunning == false then
			self._isRunning = true
			self:runAction(cc.FadeIn:create(0.2))
			self:_excute()
		end
	end 
end

function ZCMarqueeNode:initClipping( )
    local list = ccui.ListView:create()
    self:addChild(list)
    list:setContentSize(cc.size(self:getContentSize().width*0.9 - 10,self:getContentSize().height))
    list:setAnchorPoint(0,0)
    list:setPosition(self:getContentSize().width*0.1, 0)

    local layout = ccui.Layout:create()
    layout:setContentSize(list:getContentSize())
    list:pushBackCustomItem(layout)
    self.__clip = layout
end

function ZCMarqueeNode:insertAData( data )
	if data then 
		table.insert(ZCMarqueeNode.data, 1, data)
		if #ZCMarqueeNode.data > 50 then 
			table.remove(ZCMarqueeNode.data)
		end 
	end 
end