local AllPersonFuli = class( "AllPersonFuli", function ()
    return ZCPopLayer:create({opacityValue = 200, hideCallback = nil})
end)

function AllPersonFuli:create(params)
	return AllPersonFuli.new(params)
end

function AllPersonFuli:ctor(params)
	self:initData(params)
	self:initUI()
	self:show()
end

function AllPersonFuli:initData(params)
	self.rewardData = {}
    self.buyedNum = params.buyNum or 0
    local data = gameData.getDataFromCache("national_welfare_awards")

    for k,v in pairs(params.list or {}) do
        for f,g in pairs(data) do
            if tonumber(k) == tonumber(g.id) then
                g.status = v.status
                table.insert(self.rewardData, g)
            end
        end     
    end
	self:sortData()
end

function AllPersonFuli:sortData()
    -- 0人数不足 1是已完成未领取 2是已领取
    self.achievementData = {}
    local list1 = {}
    local list2 = {}
    local list3 = {}
    for k,v in pairs(self.rewardData) do
        if v.status == 0 then
            table.insert(list1,v)
        elseif v.status == 1 then
            table.insert(list2,v)
        elseif v.status == 2 then
            table.insert(list3,v)
        end
    end
    table.sort(list1,function (a,b)
        return a.id < b.id
    end)
    table.sort(list2,function (a,b)
        return a.id < b.id
    end)
    table.sort(list3,function (a,b)
        return a.id < b.id
    end)
    for k,v in pairs(list2) do
        table.insert(self.achievementData,v)
    end
    for k,v in pairs(list1) do
        table.insert(self.achievementData,v)
    end
    for k,v in pairs(list3) do
        table.insert(self.achievementData,v)
    end
end

function AllPersonFuli:initUI()
	local popBg = zc.createNormalPop({
    	tag = 4,
    	height = 435,
    	width = 584,
	})
	popBg:setPosition(zc.width/2, zc.height/2)
	self:addContent(popBg)
	self.popBg = popBg
	local titleBg = zc.createSprite('res/Main/common/popBg/tipDi.png')
    titleBg:setPosition(297,370)
    popBg:addChild(titleBg,10)

    local title = zc.createSprite('res/Main/activity/allper.png')
    title:setPosition(titleBg:getContentSize().width/2,titleBg:getContentSize().height/2)
    titleBg:addChild(title,10)

	local popSize = popBg:getContentSize()
	local close = zc.createBackButton({
        pos = cc.p(popBg:getContentSize().width, popBg:getContentSize().height),
        listener = function () 
            self:hide()
        end,
    })
    popBg:addChild(close,10)

    -- 黑底
    local black = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/popBg/di_4.png" )
    black:setContentSize(560,295)
    black:setPosition(popBg:getContentSize().width/2, popBg:getContentSize().height/2 - 43)
    popBg:addChild(black)

    local num_bg = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    num_bg:setContentSize(200,30 )
    num_bg:setPosition(popBg:getContentSize().width - 130,popBg:getContentSize().height - 78)
    popBg:addChild(num_bg)

    local buyed = zc.createLabel({
        text = zc.lang("buyed")..":",
        ap = cc.p(0,0.5),
        fontSize = 19,
        color = cc.c3b(255,247,195),
        pos = cc.p(10,num_bg:getContentSize().height/2),
    })
    num_bg:addChild(buyed)

    local num = zc.getWan(self.buyedNum)

    local buyednum = zc.createLabel({
        text = num,
        ap = cc.p(0,0.5),
        fontSize = 20,
        pos = cc.p(buyed:getContentSize().width + buyed:getPositionX() + 10,num_bg:getContentSize().height/2),
    })
    num_bg:addChild(buyednum)

    self:initTableView()
end

function AllPersonFuli:initTableView()
	local tableSize = cc.size(550,283)
    local tableView = zc.ZCTableView:create(tableSize)
    tableView:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    tableView:setPosition(17,16)
    tableView:setDelegate()
    tableView:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN) --kTableViewFillBottomUp  kTableViewFillTopDown
    local _cellWidth = 550
    local _cellHeight = 112
    -- dump(self._data)
    local function cellSizeForTable(table, cellIndex) 
        return _cellHeight, _cellWidth
    end
    local function tableCellAtIndex(table, cellIndex) 
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildRightCell(cell,cellIndex + 1,_cellHeight,_cellWidth)
        end
        self:updateRightCell(cell, cellIndex + 1,_cellHeight,_cellWidth)
        return cell
    end
    local _num = #self.achievementData
    local function numberOfCellsInTableView()
        return _num
    end
    tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    self.popBg:addChild( tableView )
    tableView:reloadData()

    self.right_tableView = tableView
end

function AllPersonFuli:buildRightCell( cell,cellIndex,_cellHeight,_cellWidth )
	-- bg
	cell._item_bg = ccui.Scale9Sprite:create(cc.rect(25, 25, 2, 10),"res/Main/grabFood/cellDi.png")
    cell._item_bg:setContentSize(540,100)
	cell._item_bg:setPosition(_cellWidth/2,_cellHeight/2)
    cell:addChild(cell._item_bg)

    local size = cell._item_bg:getContentSize()

    local item_icon,info = zc.createIconByData({
         data = {
            mainType = 1,
            type = 1, 
            id = 1,
        },
        scale = 0.65,
        pos = cc.p(60,cell._item_bg:getContentSize().height/2)
    })
    item_icon:setTouchEndedShowTip()
    cell.item_icon = item_icon
    cell._item_bg:addChild(item_icon)

    local img = zc.createSprite(info.img)
    img:setPosition(140,item_icon:getContentSize().height/2 + 10)
    cell._item_bg:addChild(img)
    cell.img = img

    local numLabel = zc.createLabel({
        text = "2000",
        fontSize = 22,
        outLine = true,
        ap = cc.p(0,0.5),
        pixel = 1.3,
        pos = cc.p(img:getPositionX() + img:getContentSize().width/2 ,img:getPositionY())
    })
    cell._item_bg:addChild(numLabel)

    cell.numLabel = numLabel

    local _nameDi2 = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(230, 30))
    _nameDi2:setAnchorPoint(0, 0.5)
    _nameDi2:setPosition(115, 28)
    cell._item_bg:addChild(_nameDi2)

	--描述
    cell._task_desc_label = zc.createLabel({
        text = "购买人数达到",
        fontSize = 19,
        ap = cc.p(0, 0.5),
        color = cc.c3b(208,190,135),
        pos = cc.p(10, _nameDi2:getContentSize().height/2),
    })
    _nameDi2:addChild(cell._task_desc_label)
    --num
    cell.numlabel = zc.createLabel({
        text = "10",
        fontSize = 22,
        ap = cc.p(0, 0.5),
        color = display.COLOR_RED,
        pos = cc.p(cell._task_desc_label:getPositionX() + cell._task_desc_label:getContentSize().width + 10, _nameDi2:getContentSize().height/2),
    })
    _nameDi2:addChild(cell.numlabel)
    --人
    cell.ci = zc.createLabel({
        text = "人",
        fontSize = 19,
        ap = cc.p(0, 0.5),
        color = cc.c3b(208,190,135),
        pos = cc.p(cell.numlabel:getPositionX() + cell.numlabel:getContentSize().width, _nameDi2:getContentSize().height/2),
    })
    _nameDi2:addChild(cell.ci)
    -- 领取
    cell.getTask = zc.createCommomBtn({
        tag = 1,
        ap = cc.p(0.5,0.5),
        pos = cc.p(size.width - 85, size.height/2),
        text = zc.lang("fetch_2"),
    })
    cell._item_bg:addChild(cell.getTask)

    cell.yilingqu = zc.createSprite("res/Main/activity/monthSign/fetched.png")
    cell.yilingqu:setPosition(cell.getTask:getPositionX(),cell.getTask:getPositionY())
    cell._item_bg:addChild(cell.yilingqu)

    cell.notenough = zc.createSprite("res/Main/activity/noenough.png")
    cell.notenough:setPosition(cell.getTask:getPositionX(),cell.getTask:getPositionY())
    cell._item_bg:addChild(cell.notenough)

end
function AllPersonFuli:updateRightCell(cell,cellIndex,_cellHeight,_cellWidth )
	local data = self.achievementData[cellIndex]
	if not data then return end
    local _list_cont = string.split(data.reward,"|")
    local info = zc.updateIconByData(cell.item_icon, {
        data = {
            mainType = tonumber(_list_cont[1]),
            type = _list_cont[2],
            id = tonumber(_list_cont[2]),
            num = tonumber(_list_cont[3]),
        },  
        showCount = true
    })
    cell.item_icon:setTouchEndedShowTip()

    cell.img:setTexture(info.img)

    cell.numLabel:setString((_list_cont[3] or 100))

    cell._task_desc_label:setString(data.desc)

    cell.numlabel:setString(tostring(zc.getWan(data.number) or 100))
    cell.ci:setPositionX(cell.numLabel:getPositionX() + cell.numLabel:getContentSize().width/2 + 5)

    local status = tonumber(data.status)
    -- 0人数不足 1是已完成未领取 2是已领取
    print("status:::",status)
    if status == 0 then
        cell.getTask:setVisible(false)
        cell.yilingqu:setVisible(false)
        cell.notenough:setVisible(true)
    elseif status == 1 then
        cell.getTask:setVisible(true)
        cell.yilingqu:setVisible(false)
        cell.notenough:setVisible(false)
    elseif status == 2 then
        cell.getTask:setVisible(false)
        cell.yilingqu:setVisible(true)
        cell.notenough:setVisible(false)
    end
    cell.getTask:setTouchEndedCall(function()
        zc.sendHttp({
            apiName = "AllPerson_Get",
            params = {id = data.id},
            successCallback = function( net_data )
                -- dump(net_data)
                net_data.noAnimation = true
                PlayerData:updataData(net_data)
                zc.createShowReward(net_data)
                for k,v in pairs(self.rewardData) do
                    if tonumber(v.id) == tonumber(data.id) then
                        v.status = 2
                    end
                end
                self:sortData()
                self.right_tableView:reloadData()
            end
        })
    end)
end

return AllPersonFuli