--[[
    FileName: GodFightListLayer.lua
    Author: wangming
    Date: 2017-03-09
    Purpose: 武神榜
]]
local GodFightListLayer = class("GodFightListLayer", function()
    return zc.createNormalDialog()
end)

function GodFightListLayer:create( params )
	local _pop = GodFightListLayer.new( params )
	return _pop
end

function GodFightListLayer:ctor( data )
    data.lastScene = "GodFight"
    PlayerData:setLastSceneData(data)
    self:initUI()

    self:freshData()
end

function GodFightListLayer:onEnter()
    if self._haveInit then
        self:freshData()
    end
    self._haveInit = true

    self:addGuide()
end

function GodFightListLayer:freshData()
    local data = PlayerData:getLastSceneData() or {}
    if data.lastScene ~= "GodFight" then
        return
    end

    self._topRankList = data.rank or {} --前五
    table.sort(self._topRankList, function( a, b )
        local _idA = tonumber(a.myRank) or 0
        local _idB = tonumber(b.myRank) or 0
        return _idA < _idB
    end)
    self._myRankList = data.rankList or {} --前五
    table.sort(self._myRankList, function( a, b )
        local _idA = tonumber(a.myRank) or 0
        local _idB = tonumber(b.myRank) or 0
        return _idA < _idB
    end)
    self._mRank = tonumber(data.myRank) or 100001 --我的
    self._fightTimes = tonumber(data.fightTimes) or 0 --剩余次数
    self._buyTimes = tonumber(data.buyTimes) or 0 --已购买次数
    self._cdTimes = tonumber(data.cdTimes) or 0 --已购买清除cd时间次数
    self._cdTime = tonumber(data.cdTime) or 0 --战斗截止时间（时间戳）
    if data.points then
        self._points = tonumber(data.points) or 0 --我的积分奖励
    else
        self._points = self._points or 0
    end
    if data.nextTime then
        self._nextGetTime = tonumber(data.nextTime) or 0 --下一次领取时间
    else
        self._nextGetTime = self._nextGetTime or 0
    end

    PlayerData:setLastSceneData(nil)
    self:refresh()
end

function GodFightListLayer:initUI()
	-- 背景图
    local bg = zc.createNormalPop({
        tag = 2,
        width = 970,
        height = 580,
        bianZOrder = 1,
    })
    bg:setPosition(zc.width*0.5, zc.height*0.5 - 10)
    self:addChild(bg)

    local _bgSize = bg:getContentSize()
    local _rightWidth = 390

    local _title = zc.createSprite("res/Main/arena/godFight/title.png")
    _title:setPosition(80, _bgSize.height)
    bg:addChild(_title, 5)

    --left
    local _leftHead = zc.createSprite("res/Main/arena/godFight/barHead.png")
    _leftHead:setAnchorPoint(0.5, 1)
    _leftHead:setPosition((_bgSize.width - _rightWidth)*0.5, _bgSize.height - 45)
    bg:addChild(_leftHead, 5)

    local _leftDi = zc.createSprite("res/Main/arena/godFight/mainBg.png")
    _leftDi:setAnchorPoint(0.5, 1)
    _leftDi:setPosition(_leftHead:getPositionX(), _leftHead:getPositionY() - _leftHead:getContentSize().height + 30)
    bg:addChild(_leftDi)


    self._leftRankNameLabs = {}
    local __w, __h = 375, 40
    for i=1, 5 do
        local _tmpY = 293 - (i - 1)*64
        if i <= 3 then
            local _numImg = zc.getSpine("wushenbang_ui")
            _numImg:playAction("wsb" .. i, true)
            _numImg:setPosition(140, _tmpY)
            _leftDi:addChild(_numImg)
        else
            local _numImg = zc.createSprite("res/Main/arena/godFight/" .. i .. ".png")
            _numImg:setPosition(140, _tmpY)
            _leftDi:addChild(_numImg)
        end

        local _node = zc.createSprite()
        _node:setContentSize(__w, __h)
        local _button = zc.createPushButton({
            normalNode = _node,
            pos = cc.p(_leftDi:getContentSize().width*0.5, _tmpY),
            endCallback = function()
                local _data = self._topRankList[i] or {}
                if not _data.userId then
                    return
                end
                zc.createOtherPlayerSelect(_data.userId)
            end
        })
        _leftDi:addChild(_button)
        local _nameLab = zc.createLabel({
            fontSize = 24,
            outLine = true,
            pos = cc.p(__w*0.5, __h*0.5)
        })
        _button:addChild(_nameLab)
        self._leftRankNameLabs[i] = _nameLab
    end

    local _rewardBtn = zc.createPushButton({
        normalFile = "res/Main/arena/godFight/rewardBtn.png",
        pos = cc.p(_leftDi:getContentSize().width - 50, 55),
        endCallback = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_14505 then
                zc.setGuideFuncNextStep(_currentGID, false)
                local function _callBack()

                end
                getGuideManager():setHeroFuncCallBack(_callBack)
                getGuideManager():startGuide()
            end
            local _pop = ZCDialog:create(255*0.6)
            LayerManager.addNode(_pop, {isPop = true})
            _pop:setTouchEndedCallback(function()
                LayerManager.removeLayout(true)
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_14507 then
                    getGuideManager():setObjTarget(self._jumpBtn)
                    getGuideManager():startGuide()
                end
            end)
            local _di = zc.createSprite("res/Main/arena/godFight/listBg.png")
            _pop:addChild(_di)
            _di:setPosition(zc.width*0.5, zc.height*0.5)

            local _dbs = gameData.getAllDataWithNoClone("arenaRankAwards")
            local _nums = table.nums(_dbs)
            for i=1, _nums do
                local _db = gameData.getDataFromCacheWithPrimaryKey("arenaRankAwards", i)
                local _award = string.split(_db.award or "", "|")
                local _num = tonumber(_award[3]) or 1
                local _type = tonumber(_award[2]) or 0
                local _richLab = zc.createRichLabel({
                    text = zc.getResRichText(_type, zc.getWan(_num)),
                    fontSize = 22,
                    anchor = cc.p(0, 0.5),
                    color = cc.c3b(253, 244, 186),
                    pos = cc.p(285, 496 - (i - 1)*39),
                })
                _di:addChild(_richLab)
            end
        end
    })
    _leftDi:addChild(_rewardBtn)
    self._rewardBtn = _rewardBtn


    local _leftBottom = ccui.Scale9Sprite:create(cc.rect(20, 10, 549, 71), "res/Main/role/trinket/sellDi.png")
    _leftBottom:setContentSize(_bgSize.width - _rightWidth, 135)
    _leftBottom:setAnchorPoint(0, 0)
    _leftBottom:setPosition(0, -2)
    bg:addChild(_leftBottom)

    local _pW = 180
    local _jumpBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("score_recruit"),
        pos = cc.p(180, 40),
        endCallback = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_14507 then
                zc.setGuideFuncNextStep(_currentGID, false)
            end
            zc.createCardExtract({id = 5})
        end
    })
    _leftBottom:addChild(_jumpBtn)
    self._jumpBtn = _jumpBtn

    local _getBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("get_score"),
        pos = cc.p(_bgSize.width - _rightWidth - _pW, _jumpBtn:getPositionY()),
        endCallback = function()
            zc.sendHttp({
                apiName = "GodFight_getScore",
                successCallback = function(net_data)
                    PlayerData:updataData(net_data)
                    self._points = 0
                    if net_data.nextTime then
                        self._nextGetTime = tonumber(net_data.nextTime) or 0 --下一次领取时间
                    end
                    self:freshLeft()
                end,
            })
        end
    })
    _leftBottom:addChild(_getBtn)
    self._getBtn = _getBtn

    local _inSize = cc.size(420, 50)
    local _infoDiSize = cc.size(90, 30)
    local _infoDi = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    _infoDi:setAnchorPoint(0.5, 0)
    _infoDi:setContentSize(_inSize)
    _infoDi:setPosition(_leftBottom:getContentSize().width*0.5, _leftBottom:getContentSize().height*0.5 + 5)
    _leftBottom:addChild(_infoDi)

    local _rankRich = zc.createRichLabel({
        text = LANGUAGE_ARENA.rank_mine .. ":",
        fontSize = 20,
        anchor = cc.p(0, 0.5),
        pos = cc.p(5, _inSize.height*0.5),
    })
    _rankRich:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
    _infoDi:addChild(_rankRich)
    -- local _infoSize = cc.size(230, 70)
    local _rankDi = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    _rankDi:setAnchorPoint(0, 0.5)
    _rankDi:setContentSize(_infoDiSize)
    _rankDi:setPosition(_rankRich:getPositionX() + _rankRich:getContentSize().width + 5, _rankRich:getPositionY())
    _infoDi:addChild(_rankDi)

    local _myRankLab = zc.createLabel({
        fontSize = 20,
        pos = cc.p(_infoDiSize.width*0.5, _infoDiSize.height*0.5),
    })
    _rankDi:addChild(_myRankLab)
    self._myRankLab = _myRankLab


    local _scoreRich = zc.createRichLabel({
        text = zc.lang("rank_reward") .. ":",
        fontSize = 20,
        anchor = cc.p(0, 0.5),
        pos = cc.p(_inSize.width*0.5, _inSize.height*0.5),
    })
    _scoreRich:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
    _infoDi:addChild(_scoreRich)

    _infoDiSize.width = _infoDiSize.width*1.15
    local _scoreDi = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    _scoreDi:setAnchorPoint(0, 0.5)
    _scoreDi:setContentSize(_infoDiSize)
    _scoreDi:setPosition(_scoreRich:getPositionX() + _scoreRich:getContentSize().width + 5, _scoreRich:getPositionY())
    _infoDi:addChild(_scoreDi)

    local _scoreImg = zc.createSprite(zc.getImgByType(zc.dataArenaRankPoint))
    _scoreImg:setAnchorPoint(0, 0.5)
    _scoreImg:setPosition(0, _infoDiSize.height*0.5)
    _scoreDi:addChild(_scoreImg)

    local _myScoreLab = zc.createLabel({
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(_scoreImg:getContentSize().width, _infoDiSize.height*0.5),
    })
    _scoreDi:addChild(_myScoreLab)
    self._myScoreLab = _myScoreLab


    --right
    local rightBg = zc.createNormalPop({
        width = _rightWidth,
        src = "res/Main/arena/godFight/rightDi.png",
        height  = _bgSize.height - 15,
        showSide = false,
    })
    rightBg:setAnchorPoint(0, 0)
    rightBg:setPosition(_bgSize.width - _rightWidth, 0)
    bg:addChild(rightBg)

    local _tableSize = cc.size(_rightWidth, 430)
    local tableview = zc.ZCTableView:create(_tableSize)
    tableview:setBounceable(true)
    tableview:setInertia(true)
    tableview:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
    tableview:setPosition(0, rightBg:getContentSize().height - _tableSize.height - 10)
    tableview:setDelegate()
    tableview:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    local cellWidth = _tableSize.width
    local cellHeight = 100
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            local _cellDi = zc.createSprite("res/Main/arena/godFight/cellDi.png")
            _cellDi:setPosition(cellWidth*0.5, cellHeight*0.5)
            cell:addChild(_cellDi)
            cell._cellDi = _cellDi

            local _iconDi = zc.createSprite("res/Main/hero/hero_item1.png")
            local _iconImg = zc.createSprite()
            _iconImg:setScale(1.3)
            _iconImg:setPosition(_iconDi:getContentSize().width*0.5, _iconDi:getContentSize().height*0.5)
            _iconDi:addChild(_iconImg)
            local _levelLab = zc.createLabel({
                text = "Lv.1",
                fontSize = 28,
                outLine = true,
                pixel = 2,
                ap = cc.p(0, 0),
                pos = cc.p(4, 2),
            })
            _iconDi:addChild(_levelLab)
            local _headIcon = zc.createPushButton({
                normalNode = _iconDi,
                scale = 0.6,
                needSwallow = false,
                needEnableWhenMoving = true,
                pos = cc.p(50, _cellDi:getContentSize().height*0.5),
                endCallback = function()
                    if tonumber(cell.userId) == tonumber(GAMEUID) then
                        return
                    end
                    zc.createOtherPlayerSelect(cell.userId)
                end
            })
            _cellDi:addChild(_headIcon)
            cell._iconImg = _iconImg
            cell._levelLab = _levelLab

            local _nameDi = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
            _nameDi:setAnchorPoint(0, 0.5)
            _nameDi:setContentSize(188, 30)
            _nameDi:setPosition(100, 65)
            _cellDi:addChild(_nameDi)

            local _typeIcon = zc.createSprite()
            _typeIcon:setScale(0.5)
            _typeIcon:setPosition(10, _nameDi:getContentSize().height*0.5)
            _nameDi:addChild(_typeIcon)
            cell._typeIcon = _typeIcon

            local _nameLab = zc.createLabel({
                fontSize = 20,
                color = cc.c3b(254, 226, 187),
                pos = cc.p(_nameDi:getContentSize().width*0.5, _nameDi:getContentSize().height*0.5),
            })
            _nameDi:addChild(_nameLab)
            cell._nameLab = _nameLab

            local _rankLab = zc.createLabel({
                color = cc.c3b(134, 74, 30),
                fontSize = 22,
                ap = cc.p(0, 1),
                pos = cc.p(0, -8),
            })
            _nameDi:addChild(_rankLab)
            cell._rankLab = _rankLab

            local _attackBtn = zc.createPushButton({
                normalFile = "res/Main/country/countryDart/atk_u.png",
                disableFile = "res/Main/country/countryDart/atk_g.png",
                pos = cc.p(_cellDi:getContentSize().width - 50, _cellDi:getContentSize().height*0.5),
                endCallback = function()
                    local _nowTime = self._cdTime - PlayerData:getTime()
                    if _nowTime > 0 then
                        zc.tipInfo(zc.lang("tips_godfight_cding"))
                        return
                    end
                    if self._fightTimes < 1 then
                        zc.tipInfo(LANGUAGE_ARENA.times_not_enough)
                        return
                    end

                    zc.sendHttp({
                        apiName = "GodFight_getEnemyInfo",
                        params = {targetUserId = cell.userId},
                        successCallback = function(net_data)
                            local enemyData = {enemys = {}}
                            for i = 1, 9 do
                                local _data = net_data[tostring(i)]
                                enemyData.enemys[i] = {}
                                if _data then
                                    enemyData.enemys[i] = _data
                                end
                            end
                            dump()
                            local _params = {
                                battleType= BattleType.GodFight,
                                toUserId = cell.userId,
                                mRank = self._mRank,
                                enemys = enemyData,
                                fightScene = 6,
                            }
                            zc.createMatrixBattle(_params)
                        end
                    })
                end
            })
            _cellDi:addChild(_attackBtn)
            cell._attackBtn = _attackBtn
        end

        local _data = self._myRankList[index + 1] or {}
        cell.userId = _data.userId
        local _rank = tonumber(_data.myRank) or 0
        local _level = tonumber(_data.level) or 0

        local _iconId = tonumber(_data.iconId) or 0
        if not inArray(_iconId, {1,2,3,4}) then
            _iconId = 1
        end
        cell._iconImg:setTexture(string.format("res/Main/hero/head/hero_head_10%s.png", tostring(_iconId)))
        cell._levelLab:setString("Lv." .. _level)
        cell._nameLab:setString(_data.userName)
        cell._rankLab:setString(LANGUAGE_ARENA.rank .. "： " .. _rank)
        local _weaponType = 1
        if _iconId == 2 or _iconId == 3 then
            _weaponType = 5
        end
        cell._typeIcon:setTexture("res/Main/role/common/weapon_icon_" .. _weaponType .. ".png")

        cell._attackBtn:setEnable(tonumber(cell.userId) ~= tonumber(GAMEUID))
        
        return cell
    end
    local function numberOfCellsInTableView()
        return #self._myRankList
    end
    tableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    rightBg:addChild(tableview)
    self._listTable = tableview

    local _cdTimeDi = zc.createSprite("res/Main/arena/godFight/timeDi.png")
    _cdTimeDi:setAnchorPoint(1, 0)
    _cdTimeDi:setPosition(_rightWidth*0.5 - 25, 20)
    rightBg:addChild(_cdTimeDi)

    local _cdTimeLab = zc.createRichLabel({
        text = "",
        fontSize = 18,
        anchor = cc.p(0, 0.5),
        color = cc.c3b(185, 1609, 102),
        pos = cc.p(5, _cdTimeDi:getContentSize().height*0.5),
    })
    _cdTimeDi:addChild(_cdTimeLab)
    self._cdTimeLab = _cdTimeLab

    local _cdClearBtn = zc.createPushButton({
        normalFile = "res/Main/arena/godFight/timeBtn.png",
        pos = cc.p(_cdTimeDi:getContentSize().width + 15, _cdTimeDi:getContentSize().height*0.5),
        endCallback = function()
            local _nowTime = self._cdTime - PlayerData:getTime()
            if _nowTime <= 0 then
                return
            end
            local _data = zc.getConsumePriceData(60, self._cdTimes + 1)
            zc.createBuyPop({
                tip = string.format(zc.lang("tips_godfight_clearcd"), tostring(_data.price)),
                special = {
                    {begin = 5, length = string.len(tostring(_data.price))}
                },
                consume = {
                    {type = 1, num = _data.price}
                },
                clickHide = true,
                callback = function()
                    zc.sendHttp({
                        apiName = "GodFight_clearCd",
                        successCallback = function(net_data)
                            PlayerData:updataData(net_data)
                            self._cdTimes = tonumber(net_data.cdTimes) or 0
                            self._cdTime = tonumber(net_data.cdTime) or 0
                            self:freshRightBottom()
                            zc.tipInfo(zc.lang("tips_godfight_clear_success"))
                        end,
                    })
                end
            })  
        end
    })
    _cdTimeDi:addChild(_cdClearBtn)
    self._cdClearBtn = _cdClearBtn

    local _timesDi = zc.createSprite("res/Main/arena/godFight/timeDi.png")
    _timesDi:setAnchorPoint(0, 0)
    _timesDi:setPosition(_rightWidth*0.5 + 15, _cdTimeDi:getPositionY())
    rightBg:addChild(_timesDi)

    local _timesLab = zc.createRichLabel({
        text = "",
        fontSize = 18,
        anchor = cc.p(0, 0.5),
        color = cc.c3b(185, 1609, 102),
        pos = cc.p(5, _timesDi:getContentSize().height*0.5),
    })
    _timesDi:addChild(_timesLab)
    self._timesLab = _timesLab

    local _buyBtn = zc.createPushButton({
        normalNode = "res/Main/common/button/common_btn2_u.png",
        pos = cc.p(_timesDi:getContentSize().width, _timesDi:getContentSize().height*0.5),
        endCallback = function()
            zc.createSourcePop("GodFightBuyPop", "src/layer/arena/GodFightBuyPop.lua", {
                times = self._buyTimes,
                fightTimes = self._fightTimes,
                callback = function( buyNum )
                    zc.sendHttp({
                        apiName = "GodFight_buyTimes",
                        params = {times = buyNum},
                        successCallback = function(net_data)
                            PlayerData:updataData(net_data)
                            self._buyTimes = tonumber(net_data.buyTimes) or 0
                            self._fightTimes = tonumber(net_data.fightTimes) or 0
                            self._cdTimes = tonumber(net_data.cdTimes) or 0
                            self:freshRightBottom()
                            zc.tipInfo(zc.lang("tips_buy_success") .. "!")
                        end,
                    })
                end,
            })
           
        end
    })
    _timesDi:addChild(_buyBtn)
    self._buyBtn = _buyBtn
end

function GodFightListLayer:refresh()
    self:freshLeft()
    self:freshRight()
end

function GodFightListLayer:freshLeft()
    for i=1, 5 do
        local _data = self._topRankList[i] or {}
        self._leftRankNameLabs[i]:setString(_data.userName)
    end

    self._myRankLab:setString(self._mRank > 100000 and LANGUAGE_ARENA.un_rank or self._mRank)
    local _tmpPoint = tonumber(self._points) or 0

    local _actionTag = 1234
    self._getBtn:stopActionByTag(_actionTag)
    if _tmpPoint == 0 then
        self._getBtn:setEnable(false)
        local function _freshTime()
            local _nowTime = self._nextGetTime - PlayerData:getTime()
            if _nowTime <= 0 then
                self._getBtn:stopActionByTag(_actionTag)
                self._getBtn:setText(zc.lang("get_score"))
                self._getBtn:setEnable(true)
            else
                local _hour = math.modf(_nowTime/(60*60))
                local _leftTime = _nowTime%(60*60)
                local _minute = math.modf(_leftTime/60)
                local _seconds = _leftTime%60
                _hour = _hour >= 10 and _hour or ("0" .. _hour)
                _minute = _minute >= 10 and _minute or ("0" .. _minute)
                _seconds = _seconds >= 10 and _seconds or ("0" .. _seconds)
                self._getBtn:setText(_hour .. ":" .. _minute .. ":" .. _seconds)
            end
        end
        schedule(self._getBtn, _freshTime, 1, _actionTag)
        _freshTime()
    else
        self._getBtn:setText(zc.lang("get_score"))
        self._getBtn:setEnable(true)
    end


    if _tmpPoint == 0 then
        local _min, _max
        local _dbs = gameData.getAllDataWithNoClone("arenaRankAwards")
        for k,v in pairs(_dbs) do
            _min = tonumber(v.minRank) or 0
            _max = tonumber(v.maxRank) or 0
            if self._mRank <= _max and self._mRank >= _min then
                _tmpPoint = string.split(v.award or "", "|")
                _tmpPoint = tonumber(_tmpPoint[3]) or 0
                break
            end
        end
    end
    self._myScoreLab:setString(_tmpPoint)
end

function GodFightListLayer:freshRight()
    self:freshRightBottom()
    self._listTable:reloadData()
end

function GodFightListLayer:freshRightBottom()    
    self._timesLab:setString(LANGUAGE_ARENA.times_left .. "：[color=ffff0000]" .. self._fightTimes .. "[/color]")

    local function _freshNoTime()
        self._cdTimeLab:setAnchorPoint(0.5, 0.5)
        self._cdTimeLab:setPositionX(self._cdTimeLab:getParent():getContentSize().width*0.5)
        self._cdTimeLab:setString(zc.lang("now_can_challange"))
        self._cdClearBtn:setVisible(false)
    end
    if self._cdTime > 0 then
        self._cdTimeLab:setAnchorPoint(0, 0.5)
        self._cdTimeLab:setPositionX(5)
        self._cdClearBtn:setVisible(true)
        local function _freshTime()
            local _nowTime = self._cdTime - PlayerData:getTime()
            if _nowTime <= 0 then
                _freshNoTime()
            else
                local _hour = math.modf(_nowTime/(60*60))
                local _leftTime = _nowTime%(60*60)
                local _minute = math.modf(_leftTime/60)
                local _seconds = _leftTime%60
                _hour = _hour >= 10 and _hour or ("0" .. _hour)
                _minute = _minute >= 10 and _minute or ("0" .. _minute)
                _seconds = _seconds >= 10 and _seconds or ("0" .. _seconds)
                self._cdTimeLab:setString(zc.lang("time_count_down") .. "：[color=ffff0000]" .. _hour .. ":" .. _minute .. ":" .. _seconds .. "[/color]")
            end
        end
        schedule(self._cdTimeLab, _freshTime, 1)
        _freshTime()
        return
    end
    _freshNoTime()

end

function GodFightListLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_14503 then
        if not PlayerData:getFuncGuideInfo(45) then
            getGuideManager():sendFuncGuideTrigger(45)
        end
        zc.setGuideFuncNextStep(_currentGID, false)
        self:addGuide()
    elseif _currentGID == GuideKey.KEY_14504 then
        if not PlayerData:getFuncGuideInfo(45) then
            getGuideManager():sendFuncGuideTrigger(45)
        end
        local function _callBack()
            getGuideManager():setObjTarget(self._rewardBtn)
            getGuideManager():startGuide()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    else
        local _flag = PlayerData:getFuncGuideInfo(45)
        if _flag then
            return
        end
        getGuideManager():sendFuncGuideTrigger(45)
        getGuideManager():setCurrentGID(GuideKey.KEY_14510)
        local function _callBack()
            getGuideManager():setFuncGuideOver()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    end
end

return GodFightListLayer