--[[
-- 国家设置
-- @author lph
-- Creation  2016-4-13
]]
local CountrySettingPop = class("CountrySettingPop",function ()
	local layer = cc.Sprite:create()
    layer:setContentSize( 565, 464 )
    layer:setAnchorPoint(cc.p(0,0))
    return layer
end)

function CountrySettingPop:create(params)
	return CountrySettingPop.new(params)
end

function CountrySettingPop:ctor(params)
    self:initData(params)
	self:initUI()
end

function CountrySettingPop:initData(params)
	self._countryData = params
    self._country_announcement = params.announcement      --公告
    self._country_announcement_temp = params.announcement --公告  用于判断公告是否修改
    self._needApply = params.needApply                    --是否需要申请 0 不需要 1 需要 
    self._needApply_temp = params.needApply               --是否需要申请 0 不需要 1 需要  用于判断申请设置是否修改
    self._joinLimitType = params.joinLimitType or 1       --加入国家条件 1任何人可加入 2需要申请 3不可加入
    self._joinLimit = params.joinLimit                    --加入条件 
    self._joinLimit_temp = params.joinLimit               --加入条件 用于判断设置是否修改
    self._country_positionId = params.countryPositionId   --职位
    self._country_name = params.name                      --国家名称
    self._country_level = params.level                    --国家等级
    self._country_monarch_name = params.monarchInfo.userName   --君主名称
    self._size = self:getContentSize()
    self._minLevel = 5      --限制最小等级
    self._maxLevel = 120    --限制最大等级
    -- dump(self._countryData, "---self._countryData---")
end

function CountrySettingPop:initUI()
    local _bg = self
    --国家名称
    local _country_name_label = zc.createLabel({
        text = self._country_name,
        fontSize = 24,
        ap = cc.p(0,0.5),
        stroke = true,
        pos = cc.p(30, 450),
    })
    _bg:addChild(_country_name_label)
    --君主 
    local _country_monarch_label = zc.createLabel({
        text = zc.lang("country_monarch") .. ":",
        fontSize = 22,
        ap = cc.p(0,0.5),
        stroke = true,
        pos = cc.p(30, 410),
    })
    _bg:addChild(_country_monarch_label)
    --君主BG
    local _monarch_name_bg_s =  zc.createScale9Sprite({
        size = cc.size(300, 40),
        file = "res/Main/country/main/country_notice_bg_s.png",
        pos = cc.p(290, 410),
    })
    _bg:addChild(_monarch_name_bg_s)
    local _monarch_name_label = zc.createLabel({
        text = self._country_monarch_name,
        fontSize = 22,
        ap = cc.p(0,0.5),
        stroke = true,
        pos = cc.p(10, 20),
    })
    _monarch_name_bg_s:addChild(_monarch_name_label)
    local _join_condition_label = zc.createLabel({
        text = zc.lang("country_join_condition") ,
        fontSize = 22,
        ap = cc.p(0,0.5),
        stroke = true,
        pos = cc.p(30, 350),
    })
    _bg:addChild(_join_condition_label)
    --条件设置BG
    local _condition_bg_s =  zc.createScale9Sprite({
        size = cc.size(180, 40),
        file = "res/Main/country/main/country_notice_bg_s.png",
        pos = cc.p(250, 350),
    })
    _bg:addChild(_condition_bg_s)
    --等级限制
    local _levelLimit_label = zc.createLabel({
        text = zc.getLevelTipShow() .. self._joinLimit .. zc.lang("country_level_above"),
        fontSize = 20,
        ap = cc.p(0.5,0.5),
        stroke = true,
        pos = cc.p(90, 20),
    })
    _condition_bg_s:addChild(_levelLimit_label)
    self._levelLimit_label = _levelLimit_label
    --左向按钮
    local _normal   = zc.createSprite("res/Main/common/button/common_btnArrow_u.png")
    local _select   = zc.createSprite("res/Main/common/button/common_btnArrow_d.png")
    local _disable  = zc.createSprite("res/Main/common/button/common_btnArrow_g.png")
    _normal:setFlipX(true)
    _select:setFlipX(true)
    _disable:setFlipX(true)
    local _left_btn = zc.createPushButton({
        normalNode        = _normal,
        selectedNode      = _select,
        disableNode       = _disable,
        needSwallow = false,
        touchScale = 0.9,
        endCallback = function()
            self:levelLimitChange(1)
        end,
        pos = cc.p( 0 ,20 ), 
    })
    _condition_bg_s:addChild(_left_btn)
    self._left_btn = _left_btn
    --右向按钮
    local _right_btn = zc.createPushButton({
        normalFile = "res/Main/common/button/common_btnArrow_u.png",
        selectedFile = "res/Main/common/button/common_btnArrow_d.png",
        disableFile = "res/Main/common/button/common_btnArrow_g.png",
        needSwallow = false,
        touchScale = 0.9,
        endCallback = function()
            self:levelLimitChange(2)
        end,
        pos = cc.p( 180 ,20 ), 
    })
    _condition_bg_s:addChild(_right_btn)
    self._right_btn = _right_btn
    if tonumber(self._joinLimit) < self._minLevel then
        self._left_btn:setEnable(false)
    end
    if tonumber(self._joinLimit) > (self._maxLevel - 5) then
        self._right_btn:setEnable(false)
    end
    --是否有权限修改设置
    local _flag_1, _flag_2 = self:isRootEdit()
    if not _flag_2 then
        self._left_btn:setEnable(false)
        self._right_btn:setEnable(false)
    end

    --修改申请条件是 国家设置基础功能，修改公告只有君主可以
    if _flag_1 then
        local _country_notice_label = zc.createLabel({
            text = zc.lang("country_notice") ,
            fontSize = 22,
            ap = cc.p(0,0.5),
            stroke = true,
            pos = cc.p(30, 270 - 30),
        })
        _bg:addChild(_country_notice_label)
        --国家公告
        local noticeBoxSize = cc.size(300, 160)
        local noticeBox = ccui.EditBox:create(noticeBoxSize, ccui.Scale9Sprite:create("res/Main/country/main/country_notice_bg_s.png"), nil, nil)
        noticeBox:setName("noticeBox")
        noticeBox:setFontSize(24)
        noticeBox:setAnchorPoint(0, 1)
        noticeBox:setText(self._country_announcement)
        noticeBox:setMaxLength(200)
        noticeBox:setInputMode(cc.EDITBOX_INPUT_MODE_ANY)
        noticeBox:setInputFlag(cc.EDITBOX_INPUT_FLAG_SENSITIVE)
        noticeBox:setReturnType(cc.KEYBOARD_RETURNTYPE_DONE )
        noticeBox:setPosition(135, 285 - 30)
        _bg:addChild(noticeBox)
        self._noticeBox = noticeBox

        if not _flag_1 then
            noticeBox:setVisible(false)
            local _notice_bg_s =  zc.createScale9Sprite({
                size = cc.size(300, 160),
                file = "res/Main/country/main/country_notice_bg_s.png",
                pos = cc.p(135, 285),
            })
            _notice_bg_s:setAnchorPoint(cc.p(0,1))
            _bg:addChild(_notice_bg_s)
            --公告内容
            -- self._notice_content_label = zc.createLabel({
            --     text = self._country_announcement,
            --     fontSize = 20,
            --     ap = cc.p(0,1),
            --     width = 270,
            --     stroke = true,
            --     pos = cc.p(0, 0),
            -- })

            local _scrollView = cc.ScrollView:create()
            _scrollView:setViewSize(cc.size(300, 140))
            _scrollView:setContentSize(cc.size(300, 140))
            _scrollView:setPosition(cc.p(0,10))
            _scrollView:ignoreAnchorPointForPosition(true)
            _scrollView:updateInset()
            _scrollView:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL) 
            _scrollView:setClippingToBounds(true)
            _scrollView:setBounceable(false)   
            _notice_bg_s:addChild(_scrollView)
            -- _scrollView:addChild(self._notice_content_label)
            -- self._notice_content_label:setPosition(cc.p(-15,self._notice_content_label:getContentSize().height))
            -- _scrollView:setContentSize(self._notice_content_label:getContentSize())
            _scrollView:setContentOffset(_scrollView:minContainerOffset())
        end
    end

    --确认按钮
    local _btn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("save"),
        pos = cc.p( self._size.width/2 + 120 ,50 ), 
        listener = function () 
            self:clickButton()
        end,
    })
    _bg:addChild(_btn)

    --申请列表
    local _applybtn = zc.createCommomBtn({
        tag = 2,
        text = zc.lang("see_apply_for"),
        pos = cc.p( self._size.width/2 - 120 ,50 ), 
        listener = function () 
            zc.sendHttp({
                apiName = "Country_applyList",
                params = {},
                successCallback = function (net_data)
                    zc.createSourcePop("CountryApplyList", "src/layer/country/CountryApplyListPop.lua", {list = net_data})
                end
            })
        end,
    })
    _bg:addChild(_applybtn)
    
    --加入权限
    self:createLimit(_bg)
end
function CountrySettingPop:createLimit(_bg)

    local _limitType = LANGUAGE_get_country_join_condition()
    self._nowJoinLimitType = self._joinLimitType
    local _join_condition_label = zc.createLabel({
        text = zc.lang("leixing") ,
        fontSize = 22,
        ap = cc.p(0,0.5),
        stroke = true,
        pos = cc.p(30, 330-40),
    })
    _bg:addChild(_join_condition_label)
    --条件设置BG
    local _condition_bg_s =  zc.createScale9Sprite({
        size = cc.size(180, 40),
        file = "res/Main/country/main/country_notice_bg_s.png",
        pos = cc.p(250, 330-40),
    })
    _bg:addChild(_condition_bg_s)
   --等级限制
    local _levelLimit_label = zc.createLabel({
        text = _limitType[self._nowJoinLimitType],
        fontSize = 20,
        ap = cc.p(0.5,0.5),
        stroke = true,
        pos = cc.p(90, 20),
    })
    _condition_bg_s:addChild(_levelLimit_label)
    --左向按钮
    local _normal   = zc.createSprite("res/Main/common/button/common_btnArrow_u.png")
    local _select   = zc.createSprite("res/Main/common/button/common_btnArrow_d.png")
    local _disable  = zc.createSprite("res/Main/common/button/common_btnArrow_g.png")
    _normal:setFlipX(true)
    _select:setFlipX(true)
    _disable:setFlipX(true)
    local _left_btn = zc.createPushButton({
        normalNode        = _normal,
        selectedNode      = _select,
        disableNode       = _disable,
        needSwallow = false,
        touchScale = 0.9,
        endCallback = function()
        end,
        pos = cc.p( 0 ,20 ), 
    })
    _condition_bg_s:addChild(_left_btn)
    --右向按钮
    local _right_btn = zc.createPushButton({
        normalFile = "res/Main/common/button/common_btnArrow_u.png",
        selectedFile = "res/Main/common/button/common_btnArrow_d.png",
        disableFile = "res/Main/common/button/common_btnArrow_g.png",
        needSwallow = false,
        touchScale = 0.9,
        endCallback = function()
        end,
        pos = cc.p( 180 ,20 ), 
    })
    _condition_bg_s:addChild(_right_btn)

    if self._joinLimitType == 1 then
        _left_btn:setEnable(false)
    elseif self._joinLimitType == 3 then
        _right_btn:setEnable(false)
    end

    _left_btn:setTouchEndedCall(function()
        if self._nowJoinLimitType > 1 then
            self._nowJoinLimitType = self._nowJoinLimitType - 1 
            _levelLimit_label:setString(_limitType[self._nowJoinLimitType])
        end
        if self._nowJoinLimitType <= 1 then
            _left_btn:setEnable(false)
        end
        _right_btn:setEnable(true)
    end)
    _right_btn:setTouchEndedCall(function()
        if self._nowJoinLimitType < 3 then
            self._nowJoinLimitType = self._nowJoinLimitType + 1
            _levelLimit_label:setString(_limitType[self._nowJoinLimitType])
        end
        if self._nowJoinLimitType >= 3 then
            _right_btn:setEnable(false)
        end
        _left_btn:setEnable(true)
    end)
end
function CountrySettingPop:levelLimitChange(tag)
    if tag == 1 then  -- 左
        if tonumber(self._joinLimit) >= self._minLevel then
            self._joinLimit = self._joinLimit - 5
        end
        if tonumber(self._joinLimit) <= (self._maxLevel-5) then
            self._right_btn:setEnable(true)
        end
        if tonumber(self._joinLimit) <= (self._minLevel-5) then
            self._left_btn:setEnable(false)
        end
    else              -- 右
        if tonumber(self._joinLimit) <= (self._maxLevel-5)then
            self._joinLimit = self._joinLimit + self._minLevel
        end
        if tonumber(self._joinLimit) >= self._minLevel then
            self._left_btn:setEnable(true)
        end
        if tonumber(self._joinLimit) >= (self._maxLevel) then
            self._right_btn:setEnable(false)
        end
    end
    local _text = zc.getLevelTipShow() .. self._joinLimit .. zc.lang("country_level_above")
    self._levelLimit_label:setText(_text)
end

function CountrySettingPop:clickButton()
    local _allFlag = ""
    local _data = {}
    local _noticeText = self._country_announcement
    if self._noticeBox then
        _noticeText = self._noticeBox:getText()
    end
    if self._country_announcement_temp ~= _noticeText then --公告
        table.insert(_data,1)
    end

    local _type
    if tonumber(self._joinLimit_temp) ~= tonumber(self._joinLimit) or self._nowJoinLimitType ~= self._joinLimitType then --等级
        table.insert(_data,3)
        _type = self._nowJoinLimitType
    end
    for k,v in pairs(_data) do
        _allFlag = _allFlag .. v 
        if tonumber(k) < #_data then
            _allFlag = _allFlag .. "_"
        end
    end

    if _allFlag == "" and not _type then
    else
        zc.sendHttp({
            apiName = "Country_editApply",
            params = {id = _allFlag,announcement = _noticeText,level = self._joinLimit,type=_type},
            successCallback = function (data)
                zc.tipInfo(zc.lang("tips_set_success"))
                --修改公告
                local CountryMain = zc.getScene("Country")
                if CountryMain then
                    if CountryMain._notice_content_label and not tolua.isnull(CountryMain._notice_content_label) then
                        CountryMain:setCountryNotice(_noticeText)
                        if CountryMain._countryData and CountryMain._countryData.announcement then
                            CountryMain._countryData.announcement = _noticeText
                        end
                    end
                    if CountryMain._countryData and CountryMain._countryData.joinLimit then
                        CountryMain._countryData.joinLimit = self._joinLimit
                    end
                    if CountryMain._countryData and CountryMain._countryData.joinLimitType then
                        CountryMain._countryData.joinLimitType = self._nowJoinLimitType
                    end
                end
            end,
        })
    end
    
end

--是否有权限修改设置
function CountrySettingPop:isRootEdit()
    local _data = self:getCountryPrivileges(self._country_positionId)
    local _flag_1 = false   -- 修改公告
    local _flag_2 = false   -- 修改加入条件及限制等级
    if _data then
        for k,v in pairs(_data) do
            if tonumber(v) == 1 then  
                _flag_1 = true
            end
            if tonumber(v) == 2 then  
                _flag_2 = true
            end
        end
    end
    return _flag_1,_flag_2
end

--国家职位权限
function CountrySettingPop:getCountryPrivileges(_positionId)
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", _positionId)
    local _privileges = ""
    if next(_data) ~= nil then
        _privileges = _data.privileges
    end
    local _data = {}
    if tonumber(_str) ~= 0 then 
        _data = string.split(_privileges,",")
    else
        _data = nil
    end
    return _data
end

return CountrySettingPop