--[[
-- 国家科技
-- @author lph
-- Creation  2016-4-8
]]
local CountryTechInfoPop = class("CountryTechInfoPop",function ()
	return ZCPopLayer:create()
end)

function CountryTechInfoPop:create(data)
	return CountryTechInfoPop.new(data)
end

function CountryTechInfoPop:ctor(data)
    self:initData(data)
	self:initUI()
    self:initList()
    self:show(false)
end

function CountryTechInfoPop:onEnter()
    self:addGuide()
end

function CountryTechInfoPop:initData(data)
	self._techdata = data.techData
	self._countryData = data.countryData
    self._callback = data.callback
    self._country_announcement = self._countryData.announcement      --公告
    self._country_positionId = self._countryData.countryPositionId   --职位
    self._country_name = self._countryData.name                      --国家名称
    self._country_level = self._countryData.level                    --国家等级
    self._country_exp = self._countryData.exp                        --国家经验
    self._country_expLimit = self._countryData.expLimit              --下一级升级所需经验
    self._size = self:getContentSize()
    self._timer = {}
    self._timeLabel = {}

    -- 国家科技
    -- 中级国家科技
    -- 高级国家科技

    local techinfo = {
        [1] = {}, -- 国家科技
        [2] = {}, -- 中级国家科技
        [3] = {}, -- 高级国家科技(高级暂时不显示)
    }
    local _data = gameData.getDataFromCache( "country_tech" )
    for k, v in pairs(_data) do
        if v and v.layerId then
            local layerId = tonumber(v.layerId)
            if techinfo[layerId] then
                local index = #techinfo[layerId] + 1
                techinfo[layerId][index] = {}
                techinfo[layerId][index].info = v
            end
        end
    end
    self._techinfo = techinfo
    self:findNowData()

end

function CountryTechInfoPop:refreshTechData(tag)
    --将科技标题和科技数据合并到一起处理
    self._allTechList = {}
    local techIdMap = {}
    self._index_tag = tag

    --当前数据
    for k,v in pairs(self._techdata.techs) do
        if tonumber(v.layerId) == tag then
            local _techData  = v
            techIdMap[tonumber(v.techId)] = "1"
            local _data = gameData.getDataFromCacheWithPrimaryKey("country_tech", v.techId)
            if next(_data) ~= nil then
                _techData.name = _data.name
                _techData.icon = _data.icon
            end
            _techData._ISOPEN = true
            _techData.weight = 0
            _techData.showLayer = _data.showLayer
            if tonumber(v.level) >= tonumber(v.levelLimit) then
                local _timeDiff = tonumber(v.researchEndTime) - PlayerData:getTime()
                if _timeDiff <= 0 then
                    _techData.weight = 10
                end
            end
            table.insert(self._allTechList,_techData)
        end
    end

    --如果该等级科技没有，使用静态数据(用于展示)
    for i = 1, #self._techinfo[tonumber(tag)] do
        local v = self._techinfo[tonumber(tag)][i]
        local techId = tonumber(v.info.id)
        if not techIdMap[techId] then
            local _info = {}
            _info.techId = techId
            _info.name = v.info.name
            _info.icon = v.info.icon
            _info.level = 0
            _info.levelLimit = 1000
            _info._ISOPEN = false
            _info.exp = 0
            _info.expLimit = 9999999
            _info.researchEndTime = 0
            _info.weight = 0
            _info.showLayer = v.info.showLayer
            table.insert(self._allTechList,_info)
        end
    end
    --排序
    local function comp(a,b)
        if tonumber(a.weight) ~= tonumber(b.weight) then
            return tonumber(a.weight) < tonumber(b.weight)
        else
            return tonumber(a.showLayer) < tonumber(b.showLayer)
        end
    end
    table.sort(self._allTechList,comp)

end

--检查当前是否达到最大等级
function CountryTechInfoPop:findNowData()
    local function checkMax(_data)
        local _isMax = true
        for i = 1, #_data do
            local v = _data[i]
            if tonumber(v.level) >= tonumber(v.levelLimit) and tonumber(v.exp) >= tonumber(v.expLimit) then
                local _timeDiff = tonumber(v.researchEndTime) - PlayerData:getTime()
                if _timeDiff <= 0 then
                else
                    _isMax = false
                    break
                end
            else
                _isMax = false
                break
            end
        end
        return _isMax
    end

    self._tabTag = 1
    for i = 1, 3 do
        self:refreshTechData(i)
        local _max = checkMax(self._allTechList)
        if not _max or i == 3 then
            self._tabTag = i
            break
        end
    end

end
function CountryTechInfoPop:initUI()
    local _techInfo_bg = zc.createSprite("res/Main/common/popBg/popBg_blue.png")
    _techInfo_bg:setPosition(zc.width*0.5, zc.height*0.5)
    self:addContent(_techInfo_bg)
    local popBgSize = _techInfo_bg:getContentSize()
    local _bianImg = zc.getScaleNode("res/Main/common/frame.png", cc.size(popBgSize.width, popBgSize.height))
    _bianImg:setPosition(popBgSize.width*0.5, popBgSize.height*0.5)
    _bianImg:setName("bianImg")
    _techInfo_bg:addChild(_bianImg, 1)
    local _b_sideImg = zc.getScaleNode("res/Main/common/popBg/shadow_b.png", cc.size(popBgSize.width + 22, 31))
    _b_sideImg:setAnchorPoint(0, 1)
    _b_sideImg:setPosition(0, 2)
    _techInfo_bg:addChild(_b_sideImg, -1)
    local _r_sideImg = zc.getScaleNode("res/Main/common/popBg/shadow_r.png", cc.size(32, 31 + popBgSize.height))
    _r_sideImg:setAnchorPoint(0, 1)
    _r_sideImg:setPosition(popBgSize.width - 5, popBgSize.height+2)
    _techInfo_bg:addChild(_r_sideImg, -1)

    --标题
    local _techInfo_title = zc.createImageView({
        src = "res/Main/country/techinfo/title.png",
        pos = cc.p(-30, _techInfo_bg:getContentSize().height - 10),
        ap = cc.p(0,0.5)
    })
    _techInfo_bg:addChild(_techInfo_title, 10)
    --左侧背景
    local _techInfo_left_bg = zc.createImageView({
        src = "res/Main/country/techinfo/techinfo_bg.jpg",
        ap = cc.p(0,0),
        pos = cc.p(9, 10) 
    })
    _techInfo_bg:addChild(_techInfo_left_bg)
    local tab_split_y = zc.createSprite("res/Main/common/tab_split_y.png")
    tab_split_y:setAnchorPoint(0.5, 0)
    tab_split_y:setPosition(_techInfo_left_bg:getPositionX()+_techInfo_left_bg:getContentSize().width+2, 9)
    _techInfo_bg:addChild(tab_split_y)
    tab_split_y:setScaleY(469/493)
    local exclamationBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/exclamation_u.png",
        selectedFile = "res/Main/common/button/exclamation_d.png",
        needSwallow = true,
        touchScale = 0.9,
        endCallback = function()
            zc.createRulePop(9)
        end,
        pos = cc.p(_techInfo_left_bg:getContentSize().width-35, _techInfo_left_bg:getContentSize().height - 30)
    })
    _techInfo_left_bg:addChild(exclamationBtn)
    --右侧背景
    local _techInfo_right_bg = zc.createImageView({
        src = "res/Main/country/main/country_pop_right_bg.png",
        ap = cc.p(1,0),
        pos = cc.p(_techInfo_bg:getContentSize().width-7, 8) 
    })
    _techInfo_bg:addChild(_techInfo_right_bg)
    self._techInfo_bg = _techInfo_bg

    self._techInfo_right_bg = _techInfo_right_bg


    --关闭按钮
    local _closeButton = zc.createBackButton({
        pos = cc.p(_techInfo_bg:getBoundingBox().width-10  , _techInfo_bg:getBoundingBox().height), 
        listener = function () 
            LayerManager.removeLayout(true)
        end,
    })
    _techInfo_bg:addChild(_closeButton, 10)
end

function CountryTechInfoPop:initList()
    local _techInfo_size = self._techInfo_right_bg:getContentSize()
    self._techInfo_size = _techInfo_size
    self._openLevel1 = 5 --开启中级科技的等级
    self._openLevel2 = 10 --开启高级科技的等级
    local techinfoTitleName, techinfoTitleDes = LANGUAGE_get_country_tech_types()

    -- 顶部
    self._topbgList = {}
    self._nameBgList = {}
    for i = 1, 3 do
        local _topBg = cc.Sprite:create( "res/Main/role/common/top_bg.jpg" )
        _topBg:setAnchorPoint( 0.5, 1 )
        _topBg:setPosition( cc.p(self._techInfo_right_bg:getContentSize().width/2, _techInfo_size.height-5 - (i-1)* 50) )
        self._techInfo_right_bg:addChild( _topBg , 1)
        _topBg:setScaleX( (_techInfo_size.width - 6)/_topBg:getContentSize().width )
        self._topbgList[#self._topbgList+1] = _topBg
        local nameBgSize = cc.size(211,32)
        local namePos = cc.p(_topBg:getPositionX(), _topBg:getPositionY()- _topBg:getContentSize().height/2)
        local arrowPos = cc.p(nameBgSize.width+100, nameBgSize.height/2)
        local _name = techinfoTitleName[i]
        if i > self._tabTag then
            nameBgSize = cc.size(390,32)
            _name = techinfoTitleName[i]..techinfoTitleDes[i]
            namePos = cc.p(_topBg:getPositionX() - 40, _topBg:getPositionY()- _topBg:getContentSize().height/2)
            arrowPos = cc.p(nameBgSize.width+52, nameBgSize.height/2)
        end
        local nameBg = zc.getScaleNode("res/Main/role/common/name_bg.png", nameBgSize )
        nameBg:setPosition( namePos )
        self._techInfo_right_bg:addChild(nameBg, 1)
        self._nameBgList[#self._nameBgList+1] = nameBg

        local titleName = zc.createLabel({
            text = _name,
            outLine = true,
            fontSize = 22,
            pos = cc.p(nameBg:getContentSize().width/2, nameBg:getContentSize().height/2),
            -- color = cc.c3b(219,212,167),
        })
        titleName:setName("titleName")
        nameBg:addChild(titleName)

        local arrow_right = zc.createSprite("res/Main/common/arrow_new.png")
        arrow_right:setScale(0.8)
        arrow_right:setRotation(180)
        arrow_right:setPosition(arrowPos)
        nameBg:addChild(arrow_right)
        _topBg._arrow = arrow_right

        -- local myScale9 = zc.getScaleNode("res/Main/setting/scale9_1.png", cc.size(586, 40))
        local myScale9 = zc.createSprite()
        myScale9:setContentSize( cc.size(586, 40) )
        local selectBtn = zc.createPushButton({
            normalNode = myScale9,
            needSwallow = true,
            endCallback = function()
                local arrow_rotation = arrow_right:getRotation()
                if arrow_rotation == 180 then --展开
                    self:touchHandle(1, i)
                    arrow_right:setRotation(-90)
                    for j = 1,3 do
                        if i ~= j then
                            self._topbgList[j]._arrow:setRotation(180)
                        end
                    end
                elseif arrow_rotation == -90 then --收起
                    self:touchHandle(2, i)
                    arrow_right:setRotation(180)
                end

            end,
            pos = cc.p(_topBg:getContentSize().width/2,_topBg:getContentSize().height/2)
        })
        _topBg:addChild(selectBtn)
    end

    --
    self:firstSet()

end
    
function CountryTechInfoPop:firstSet()
    local techinfoTitleName, techinfoTitleDes = LANGUAGE_get_country_tech_types()
    for i = 1, 3 do
        local _topBg = self._topbgList[i]
        local nameBg = self._nameBgList[i]
        local nameBgSize = cc.size(211,32)
        local namePos = cc.p(_topBg:getPositionX(), _topBg:getPositionY()- _topBg:getContentSize().height/2)
        local arrowPos = cc.p(nameBgSize.width+100, nameBgSize.height/2)
        local _name = techinfoTitleName[i]
        if i > self._tabTag then
            nameBgSize = cc.size(390,32)
            _name = techinfoTitleName[i]..techinfoTitleDes[i]
            namePos = cc.p(_topBg:getPositionX() - 40, _topBg:getPositionY()- _topBg:getContentSize().height/2)
            arrowPos = cc.p(nameBgSize.width+52, nameBgSize.height/2)
        end
        nameBg:setContentSize(nameBgSize)
        nameBg:setPosition(namePos)
        local titleName = nameBg:getChildByName("titleName")
        titleName:setString(_name)
        titleName:setPosition(nameBgSize.width/2,nameBgSize.height/2)
        _topBg._arrow:setPosition( arrowPos )
    end
    self._topbgList[self._tabTag]._arrow:setRotation(-90)
    for j = 1,3 do
        if self._tabTag ~= j then
            self._topbgList[j]._arrow:setRotation(180)
        end
    end
    self:touchHandle(1, self._tabTag)
end

--点击处理
function CountryTechInfoPop:touchHandle(_type, _tag) -- _type:1展开、2收起
    if not self._techInfoTable then
        self:initTechInfoList()
    end
    --_tag：1国家科技、2中级国家科技、3高级国家科技
    if _type == 1 then
        self._techInfoTable:setVisible(true)
        if _tag == 1 then
            self._topbgList[2]:setPositionY(48+48)
            self._nameBgList[2]:setPositionY( self._topbgList[2]:getPositionY()- self._topbgList[2]:getContentSize().height/2 )
            self._topbgList[3]:setPositionY(48)
            self._nameBgList[3]:setPositionY( self._topbgList[3]:getPositionY()- self._topbgList[3]:getContentSize().height/2 ) 
            self._techInfoTable:setPositionY(48+48)
        elseif _tag == 2 then
            self._topbgList[2]:setPositionY(self._techInfo_size.height-55)
            self._nameBgList[2]:setPositionY( self._topbgList[2]:getPositionY()- self._topbgList[2]:getContentSize().height/2 )
            self._topbgList[3]:setPositionY(48)
            self._nameBgList[3]:setPositionY( self._topbgList[3]:getPositionY()- self._topbgList[3]:getContentSize().height/2 )
            self._techInfoTable:setPositionY(48)
        elseif _tag == 3 then
            self._topbgList[2]:setPositionY(self._techInfo_size.height-55)
            self._nameBgList[2]:setPositionY( self._topbgList[2]:getPositionY()- self._topbgList[2]:getContentSize().height/2 )
            self._topbgList[3]:setPositionY(self._techInfo_size.height-55-50)
            self._nameBgList[3]:setPositionY( self._topbgList[3]:getPositionY()- self._topbgList[3]:getContentSize().height/2 )
            self._techInfoTable:setPositionY(0)
        end
        self:refreshTechData(_tag)
        self._techInfoTable:reloadData()
    elseif _type == 2 then
        if _tag == 1 then
            self._topbgList[2]:setPositionY(self._techInfo_size.height-55)
            self._nameBgList[2]:setPositionY( self._topbgList[2]:getPositionY()- self._topbgList[2]:getContentSize().height/2 )
            self._topbgList[3]:setPositionY(self._techInfo_size.height-55-50)
            self._nameBgList[3]:setPositionY( self._topbgList[3]:getPositionY()- self._topbgList[3]:getContentSize().height/2 )
        elseif _tag == 2 then
            self._topbgList[3]:setPositionY(self._techInfo_size.height-55-50)
            self._nameBgList[3]:setPositionY( self._topbgList[3]:getPositionY()- self._topbgList[3]:getContentSize().height/2 )
        elseif _tag == 3 then
        end
        self._techInfoTable:setVisible(false)
    end
end
function CountryTechInfoPop:initTechInfoList()
    local _tableSize = cc.size(500, 365 - 50)
    local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setPosition(3, 0)
    _tableView:setInertia(true)
    _tableView:setBounceable(true)
    _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL)
    -- _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_BOTH)
    _tableView:setDelegate()
    _tableView:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    self._techInfo_right_bg:addChild(_tableView)
    self._techInfoTable = _tableView

    local _cellSize = cc.size(500, 112)

    local function numberOfCellsInTableView( table )
        return #self._allTechList
    end
    local function cellSizeForTable( table, index )
        _cellSize = cc.size(500, 112)
        return _cellSize.height , _cellSize.width
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        if cell then
            cell:removeAllChildren()
        else
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(_cellSize)
        end

        local _di = zc.createImageView({
            src = "res/Main/country/techinfo/techinfo_item_bg.png",
            ap = cc.p(0,0.5),
            pos = cc.p(13, 55),
        })
        cell:addChild(_di)
        self:createOneCell(_di, index)
        return cell
    end
    _tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    _tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    _tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    _tableView:reloadData()
end

function CountryTechInfoPop:createOneCell( cell, index )
    local _tech_data = self._allTechList[index+1]
    if _tech_data then
        --科技icon
        local _itemIcon = zc.createIconByData({
            data = {
                mainType = zc.mainTypeTech,
                type = 1, 
                id = tonumber(_tech_data.techId) or 1,
                level = zc.getLevelTipShow().._tech_data.level,
            }, 
            showLevel = false,
            pos = cc.p(55, 50), 
        })
        _itemIcon:setScale(0.55)
        cell:addChild(_itemIcon)

        local gray_namebg = zc.getScaleNode("res/Main/country/main/gray_bg.png", cc.size(222, 32))
        gray_namebg:setAnchorPoint(0, 0.5)
        gray_namebg:setPosition(96, 46+18)
        cell:addChild(gray_namebg)
        local _name_label = zc.createLabel({
            text = _tech_data.name.."  " .. zc.getLevelTipShow() .. _tech_data.level,
            fontSize = 18,
            outLine = true,
            ap = cc.p(0,0.5),
            pos = cc.p(7, gray_namebg:getContentSize().height/2),
        })
        gray_namebg:addChild(_name_label) 

        local gray_starbg = zc.getScaleNode("res/Main/country/main/gray_bg.png", cc.size(222, 32))
        gray_starbg:setAnchorPoint(0, 0.5)
        gray_starbg:setPosition(96, 46-18)
        cell:addChild(gray_starbg)

        self:initLevelStar(gray_starbg,_tech_data)
        --捐赠按钮

        --时间
        local _timeDiff = tonumber(_tech_data.researchEndTime) - PlayerData:getTime()

        --默认
        local _btnState = 1 --1捐献、2升级(君主、丞相)、3升级(普通)、4满级、5未开启、6正在升级
        if not _tech_data._ISOPEN then
            _btnState = 5   
        end
        --科技升级        
        if tonumber(_tech_data.exp) >= tonumber(_tech_data.expLimit) then
            _btnState = 3
        end
        if tonumber(_tech_data.level) >= tonumber(_tech_data.levelLimit) and tonumber(_tech_data.exp) >= tonumber(_tech_data.expLimit) then
            _name_label:setString(_tech_data.name.."  " .. zc.getLevelTipShow() .._tech_data.level.." (" .. zc.lang("already_full_level") .. ")")
            _btnState = 4
        end
        if _timeDiff and _timeDiff > 0 then
            _btnState = 6
        end

        if _btnState == 2 or _btnState == 3 then
            local _btn = zc.createPushButton({
                normalFile = "res/Main/common/button/common_btnSquare1_u.png",
                selectedFile = "res/Main/common/button/common_btnSquare1_d.png",
                outLine = true,
                fontSize = 22,
                fontColor = cc.c3b(255, 241, 121),
                color2 = cc.c3b(98, 17, 17),
                needSwallow = false,
                touchScale = 0.9,
                text = zc.lang("upgrade"),
                endCallback = function()
                    if _btnState == 2 then
                        zc.sendHttp({
                            apiName = "Country_upgradeTech",
                            params = {id = _tech_data.id},
                            successCallback = function (net_data)
                                self:updateTechTableView(_tech_data, net_data)
                            end
                        })
                    elseif _btnState == 3 then
                        local function _callBack(_techData)
                            self:updateTechTableView(_tech_data,_techData)
                            --更新国家信息
                            self:updateCountryView(_techData)
                        end
                        local function _levelUp(_data)
                            self:updateTechTableView(_tech_data, _data)
                        end
                        local _data = {techData = _tech_data,data = self._techdata,callback = _callBack,levelUp=_levelUp}
                        zc.createSourcePop( "CountryContribute", "src/layer/country/CountryContributePop.lua", _data)
                    end
                end,
                pos = cc.p( 395 ,50 ),
            })
            cell:addChild(_btn)
        else
            if _btnState ~= 6 then
                local _normal = zc.createSprite("res/Main/country/techinfo/contribute_btn_u.png")
                local _select = zc.createSprite("res/Main/country/techinfo/contribute_btn_d.png")
                if _btnState == 4 or _btnState == 5 then
                    zc.setGray(_normal)
                    zc.setGray(_select)
                end

                local _contribute_btn = zc.createPushButton({
                    normalNode = _normal,
                    selectedNode = _select,
                    needSwallow = false,
                    touchScale = 0.9,
                    endCallback = function()                     
                        local _currentGID = getGuideManager():getCurrentGID()
                        if _currentGID == GuideKey.KEY_14102 then
                            getGuideManager():setFuncGuideOver()
                        end
                        if _btnState == 4 then
                            zc.tipInfo(zc.lang("tips_country_tech_full_level"))
                        elseif _btnState == 5 then
                            zc.tipInfo(zc.lang("tips_country_tech_cannnot_donate"))
                        else
                            local function _callBack(_techData)
                                self:updateTechTableView(_tech_data,_techData)
                                --更新国家信息
                                self:updateCountryView(_techData)
                            end
                            local function _levelUp(_data)
                                self:updateTechTableView(_tech_data, _data)
                            end
                            local _data = {techData = _tech_data,data = self._techdata,callback = _callBack,levelUp=_levelUp}
                            zc.createSourcePop( "CountryContribute", "src/layer/country/CountryContributePop.lua", _data)
                        end
                    end,
                    pos = cc.p( 395 ,50 ),
                })
                cell:addChild(_contribute_btn)
                if index == 0 then
                    self._guideBtn = _contribute_btn
                end
            end
        end


        if _timeDiff > 0 then
            if _btn then
                _btn:setVisible(false)
            end
            local levelTip = zc.createLabel({
                text = zc.lang("level_up_time_count_down") .. "：",
                stroke = false,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(335, 70),
                color = cc.c3b(90,50,41),
            })
            cell:addChild(levelTip)
            local shalou = zc.getSpine("shalou")
            shalou:setScale(0.5)
            shalou:setPosition(350, 35)
            shalou:playAction("animation", true)
            cell:addChild(shalou)
            local _strTime = zc.getTimeHMS(_timeDiff)
            local _time_label = zc.createLabel({
                text = _strTime,
                fontSize = 18,
                ap = cc.p(0,0.5),
                outLine = true,
                pos = cc.p(370 ,35),
                color = display.COLOR_GREEN,
            })
            cell:addChild(_time_label)
            schedule(_time_label,function()
                _timeDiff = _timeDiff - 1
                local _strTime = zc.getTimeHMS(_timeDiff)
                _time_label:setString(_strTime)
                if _timeDiff <= 0 then
                    _time_label:stopAllActions()
                end
            end,1.0)
        end
    end
end
--定时器
function CountryTechInfoPop:selfTimerecord(_data)
    self:stopAllActions()
    local _timeDiff = tonumber(_data.researchEndTime) - PlayerData:getTime()
    if _timeDiff > 0 then
        schedule(self,function()
            _timeDiff = _timeDiff - 1
            if _timeDiff <= 0 then
                self:stopAllActions()
                _data.researchEndTime = 0
                self:findNowData()
                self:firstSet()
            end
        end,1.0)
    end
end
--科技列表刷新
function CountryTechInfoPop:updateTechTableView(_tech_data,_techData)
    for k,v in pairs(self._allTechList) do
        if tonumber(v.id) == tonumber(_tech_data.id) then
            for _k,_v in pairs(v) do
                if _techData[_k] then
                    self._allTechList[k][_k] = _techData[_k]
                end
            end
            self:selfTimerecord(v)
            break
        end
    end
    self:isOpenNextTechList()
    self._techInfoTable:reloadDataAndScrollToCurrentCell()          
end

--是否开启下一等级列表
function CountryTechInfoPop:isOpenNextTechList()
    -- dump(self._allTechList, "---self._allTechList--")
    local _flag = false
    for k,v in pairs(self._allTechList) do
        if v.level and v.levelLimit then
            if tonumber(self._tabTag) == tonumber(v.layerId) and 
                tonumber(v.level) >= tonumber(v.levelLimit) and
                tonumber(v.exp) >= tonumber(v.expLimit) then
                _flag = true
            else
                _flag = false
                break
            end
        end
    end
    if _flag then 
        zc.sendHttp({
            apiName = "Country_techList",
            successCallback = function (data)
                self._techdata = data
            end,
        })
    end
end

--更新国家信息
function CountryTechInfoPop:updateCountryView(_techData)
    local _data = PlayerData:getCountryInfo()
    _data.exp = _techData.countryExp
    _data.level = _techData.countryLevel 
    _data.expLimit = _techData.countryExpLimit 

    self._callback()
end

--科技星级
function CountryTechInfoPop:initLevelStar(_bg,_techData) 
    local _src_1 = "res/Main/common/common_hero_star_1.png"
    local _src_2 = "res/Main/common/common_hero_star_2.png"
    --
    local _starLimit = 3
    local _data = gameData.getDataFromCache( "country_tech_level", {techId = _techData.techId,level = _techData.level} )
    if next(_data) ~= nil then
        _starLimit = tonumber(_data.starNum)
    end
    local _expTem = tonumber(_techData.expLimit)/tonumber(_starLimit)
    for i=1,_starLimit do
        local _starImg = zc.createImageView({
                src = _src_2,
                pos = cc.p(20+(i-1)*30, _bg:getContentSize().height/2),
                scale = 0.75,
            })
        _bg:addChild(_starImg)
    end
    for i=1,_starLimit do
        if tonumber(_techData.exp) >= tonumber(_expTem)*i then
            local _starImg = zc.createImageView({
                    src = _src_1,
                    pos = cc.p(20+(i-1)*30, _bg:getContentSize().height/2),
                    scale = 0.75,
                })
            _bg:addChild(_starImg)
        end
    end
end

--国家职位权限
function CountryTechInfoPop:getCountryPrivileges(_positionId)
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", _positionId)
    local _privileges = ""
    if next(_data) ~= nil then
        _privileges = _data.privileges
    end
    local _data = {}
    if tonumber(_str) ~= 0 then 
        _data = string.split(_privileges,",")
    else
        _data = nil
    end
    return _data
end
--是否可以升级科技
function CountryTechInfoPop:isCanUpgrade(_positionId)
    local _data = self:getCountryPrivileges(_positionId)
    local _flag = false
    if _data then
        for k,v in pairs(_data) do
            if tonumber(v) == 7 then  --可以升级
                _flag = true
            end
        end
    end
    return _flag
end

--------------------------------引导------------------------------
function CountryTechInfoPop:addGuide()
    local _flag = PlayerData:getFuncGuideInfo(41)
    if _flag then
        return
    end
    getGuideManager():sendFuncGuideTrigger(41)
    getGuideManager():setCurrentGID(GuideKey.KEY_14101)
    local function _callBack()
        if self._guideBtn then
            getGuideManager():setObjTarget(self._guideBtn)
            getGuideManager():startGuide()
        else
            getGuideManager():setFuncGuideOver()
        end
    end
    getGuideManager():setHeroFuncCallBack(_callBack)
    getGuideManager():startGuide()
end

return CountryTechInfoPop