--[[
	校场功能界面
	唐实聪
    2016.5.12
]]
local DrillFieldLayer = class("DrillFieldLayer", function()
	return ZCDialog:create()
end)

function DrillFieldLayer:create( params )
	return DrillFieldLayer.new( params )
end

function DrillFieldLayer:ctor( params )
	self:initData( params )
	self:initUI()
end
-- 战斗返回刷新界面
function DrillFieldLayer:onEnter()
    if self._refresh then
        self._refresh = nil
        self:refreshData()
    else
        self:trainingOver()
    end
    
    -- 突飞卡数据
    self._expCardData = PlayerData:getPropByMainTypeAndSubType(1,1001) or {}
    -- 突飞卡数量
    self._expCardNum = self._expCardData and ( tonumber( self._expCardData.num ) or 0 ) or 0
    
    -- 战斗特效
    zc.addEventListener({name = EVENT_NAME_BATTLE_PLAY_EFFECT, callback = function(event)
        local data      = event.data
        local node      = data.node
        local zorder    = data.zorder
        if node ~= nil then
            if zorder == nil then
                zorder = node:getLocalZOrder()
            end
            --[[设置层级]]
            self._heroLayer:addChild( node, zorder )
        end
    end})

    --功能引导
    self:addGuide()
end

function DrillFieldLayer:onCleanup()
    self:stopTimer()
    zc.removeEventListener(EVENT_NAME_BATTLE_PLAY_EFFECT)

    -- 刷新校场红点
    PlayerData:setDrillFieldCanDo( self._positionData )
    
    self:removeAllChildren()
    local manager = ccs.ArmatureDataManager:getInstance()
    manager:removeArmatureFileInfo("res/image/battle/ef_hit_jizhong/ef_hit_jizhong.csb")
    manager:removeArmatureFileInfo("res/image/battle/dazhao_ef/dazhao_ef.csb")
    manager:removeArmatureFileInfo( "res/animation/shengjitexiao/shengjitexiao.csb", true )
    local _forms = PlayerData:getNowFormationFiles()
    for k, v in pairs( self._record ) do
        -- 如果已上阵，不删除
        local _path, _resId = zc.battle.getHeroArmaturePathByResId( k )
        if not _forms[_resId] then
            manager:removeArmatureFileInfo( _path )
        end
    end
    helper.collectMemory(true)
end

function DrillFieldLayer:initData( params )
    -- dump(params,"params")
    -- 训练位类型数据
    self._typeData = params.data.types
    -- 训练位数据
	self._positionData = params.data.positions
    -- 进入校场，更新武将信息
    for k,v in pairs(self._positionData) do
        if v and v.hero and v.hero.id and v.hero.level then
            local _updateInfo = {}
            _updateInfo.id = v.hero.id
            _updateInfo.level = v.hero.level
            PlayerData:updateGeneralInfo( _updateInfo )
        end
    end

	-- 排序位置数据
	table.sort(self._positionData, function( a, b )
		return tonumber( a.position ) < tonumber( b.position )
	end)

    -- 经验结算
    local _tss = tonumber( params.tss ) or 0
    for i, v in ipairs( self._positionData ) do
        if v.expYield and v.startTime then
            v.trainExp = tonumber( v.expYield )*( _tss - tonumber( v.startTime ) )
            v.trainExp = math.floor( v.trainExp )
        else
            v.trainExp = 0
        end
    end

	-- 建筑信息
	self._houseInfo = params.houseInfo
	-- 校场静态表，id是效果id
	self._effectData = {}
	-- 开启位置的校场等级，不会改，只跟表有关
	self._openData = {}
    local _datas = gameData.getAllDataWithNoClone("houseEffect_training")
	for i = 1, table.nums( _datas ) do
        local _data = _datas[tostring( i )]
		self._effectData[tonumber( _data.id )] = _data
		for i = 1, 2 do
			local pos = tonumber( _data["position"..i] )
			if pos ~= 0 and not self._openData[pos] then
				local npc = _data["npcGroup"..i]
				local level = gameData.getDataFromCache("house_level", {houseId = self._houseInfo.houseId, effectId = _data.id}).level
				self._openData[pos] = {
					npc = npc,
					level = level
				}
			end
		end
	end
	-- dump( self._openData, "self._openData" )


    -- 训练位当前建筑等级的效果，不管是否打过npc，跟建筑等级相关
    self._expAddData = {}
    local _houseLevelData1 = gameData.getDataFromCache("house_level", {houseId = self._houseInfo.houseId, level = 1})
    local _houseLevelData2 = gameData.getDataFromCache("house_level", {houseId = self._houseInfo.houseId, level = self._houseInfo.level})
    local effectId_1 = tonumber(_houseLevelData1.effectId) or 0
    local effectId_2 = tonumber(_houseLevelData2.effectId) or 0
    for i = effectId_1, effectId_2 do
        local effectData = self._effectData[i]
        self._expAddData[tonumber(effectData.position1)] = effectData.expRate1
        self._expAddData[tonumber(effectData.position2)] = effectData.expRate2
    end

    -- 转生起始等级
    self._advanceBeginLevel = 50
    -- 转生增加等级
    self._advanceLevel = 5
    -- 连续突飞间隔
    self._interval = 0.2

    -- 连续突飞的配置
    self._upgradeConfig = {1, 2, 3, 4, 5, 7, 10, 15}

    -- 每张突飞卡的经验值
    self._cardExpNum = math.floor( tonumber( PlayerData:getBaseInfo().level )*50*45*5/24 )


    -- 记录需要清理的英雄
    self._record = {}
    -- 敌人动画数据
    self._enemyData = {
        image = "xunlianxiaoren",
    }
    self._record["xunlianxiaoren"] = true

    self._size = self:getContentSize()
end


function DrillFieldLayer:initUI()
	-- 背景
	local bg = cc.Sprite:create( "res/Main/drillField/drillField_bg.jpg" )
	bg:setPosition( self._size.width/2, self._size.height/2 )
	self:addChild( bg )
	zc.setBgSize( bg )
	-- 标题
	local title = cc.Sprite:create( "res/Main/drillField/drillField_title.png" )
	title:setAnchorPoint( 0, 1 )
	title:setPosition( 80, self._size.height )
	self:addChild( title, 40 )
	
	-- 训练位列表
	self:initList()
	-- 训练位信息
	self:initListInfo()
	-- 武将信息
	self:initHeroInfo()



    -- 敌人层
    local enemyLayer = cc.Layer:create()
    enemyLayer:setContentSize( self._size )
    self:addChild( enemyLayer, 10 )
    self._enemyLayer = enemyLayer
    -- 创建敌人
    self:createEnemy()



    -- 武将层
    local heroLayer = cc.Layer:create()
    heroLayer:setContentSize( self._size )
    self:addChild( heroLayer, 20 )
    self._heroLayer = heroLayer

    -- 创建一个默认的武将
    for i, v in ipairs( self._positionData ) do
        if ( tonumber( v.status ) or 0 ) == 1 then
            -- 已解锁
            if v.hero and v.hero.id then
                -- 有英雄
                self._listIndex = i
                self:createHero()
                break
            end
        end
    end

    --返回按钮
    local back = zc.createTopBackButton({
        listener = function()
            LayerManager.removeLayout()
        end,
    })
    self:addChild( back, 40 )
    self._backBtn = back
end
-- 训练位列表
function DrillFieldLayer:initList()
	-- 箭头
	local arrow_up = cc.Sprite:create( "res/Main/drillField/drillField_arrow_up.png" )
	arrow_up:setPosition( 55, 570 )
	self:addChild( arrow_up, 30 )
    arrow_up:runAction(
        cc.RepeatForever:create(
            cc.Sequence:create(
                cc.MoveTo:create(
                    2, cc.p( 55, 580 )
                ),
                cc.MoveTo:create(
                    2, cc.p( 55, 570 )
                )
            )
        )
    )
	local arrow_down = cc.Sprite:create( "res/Main/drillField/drillField_arrow_down.png" )
	arrow_down:setPosition( 55, 80 )
	self:addChild( arrow_down, 30 )
    arrow_down:runAction(
        cc.RepeatForever:create(
            cc.Sequence:create(
                cc.MoveTo:create(
                    2, cc.p( 55, 70 )
                ),
                cc.MoveTo:create(
                    2, cc.p( 55, 80 )
                )
            )
        )
    )
	-- list
    local listBg = cc.Sprite:create( "res/Main/drillField/drillField_list_bg.png" )
    listBg:setPosition( 60, 325 )
    self:addChild(listBg,30)
	local listTableview = zc.ZCTableView:create(cc.size(120, 450))--185, 435
    listTableview:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
    listTableview:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    listTableview:setPosition(cc.p(0, 100))
    listTableview:setDelegate()
    self:addChild(listTableview,30)
    self._listTableview = listTableview
    local cellWidth = 120
    local cellHeight = 95
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
	        local cellBg = cc.Sprite:create()
	        cellBg:setContentSize( cellWidth, cellHeight )
	        cellBg:setPosition( cellWidth/2, cellHeight/2 )
	        cell:addChild( cellBg )
            cell._cellBg = cellBg
        end
        local cellBg = cell._cellBg
        cellBg:removeAllChildren()

        xpcall(function()
            index = index + 1
            local data = self._positionData[index]
            local endCallback = nil
            if data then
                if tonumber( data.status ) == 0 then
                    -- 可攻打
                    local color = data.color or 1
                    local bg = cc.Sprite:create( "res/Main/hero/hero_item"..color..".png" )
                    bg:setPosition( cellWidth/2, cellHeight/2 )
                    bg:setScale( 0.75 )
                    cellBg:addChild( bg )
                    local sp = cc.Sprite:create( "res/Main/drillField/drillField_head_canActive.png" )
                    sp:setPosition( cellWidth/2, cellHeight/2 )
                    cellBg:addChild( sp )
                    local can_attack = zc.createSprite("res/Main/drillField/drillField_can_attack.png")
                    can_attack:setAnchorPoint(0.5, 0.5)
                    -- can_attack:setScale(0.8)
                    can_attack:setPosition(cellWidth/2, 17)
                    cellBg:addChild(can_attack)
                    can_attack:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeOut:create(1.2),cc.FadeIn:create(1.2))))
                    endCallback = function()
                        --功能引导
                        local _currentGID = getGuideManager():getCurrentGID()
                        if _currentGID == GuideKey.KEY_12707 then
                            zc.setGuideFuncNextStep(_currentGID)
                        end
                        -- 开始挑战
                        self:starFight( self._openData[index].npc or 0, data.id )
                    end
                elseif tonumber( data.status ) == 1 then
                    -- 已开启
                    if data.hero and data.hero.id then
                        -- 有英雄在训练
                        local color = data.color or 1
                        local bg = zc.createIconByData({
                            data = {
                                mainType = zc.mainTypeSoldier,
                                type = data.hero.heroId, 
                                id = data.hero.heroId,
                                quality = data.color or 1,
                                level = zc.getLevelTipShow()..tostring( data.hero.level ),
                                reincarnate = data.hero.reincarnate,
                            },
                            quality = data.quality,
                            showLevel = true,
                            pos = cc.p( cellWidth/2, cellHeight/2 ), 
                        })
                        bg:setScale( 0.75 )
                        cellBg:addChild( bg )
                        endCallback = function()
                            -- 切换英雄
                            self._listIndex = index
                            self:createHero()
                        end
                    else
                        -- 没有英雄在用
                        local color = data.color or 1
                        local bg = cc.Sprite:create( "res/Main/hero/hero_item"..color..".png" )
                        bg:setPosition( cellWidth/2, cellHeight/2 )
                        bg:setScale( 0.75 )
                        cellBg:addChild( bg )
                        local sp = cc.Sprite:create( "res/Main/drillField/drillField_can_training.png" )
                        sp:setPosition( cellWidth/2, cellHeight/2 )
                        cellBg:addChild( sp )
                        endCallback = function()
                            --功能引导
                            local _currentGID = getGuideManager():getCurrentGID()
                            if _currentGID == GuideKey.KEY_12710 then
                                zc.setGuideFuncNextStep(_currentGID)
                            end
                            -- 创建英雄列表
                            self:createHeroList( index )
                        end
                        sp:runAction(
                            cc.RepeatForever:create(
                                cc.Sequence:create(
                                    cc.FadeTo:create( 1, 80 ),
                                    cc.FadeTo:create( 1, 255 )
                                )
                            )
                        )
                    end
                end
            else
                -- 建筑等级不够
                local color = 1
                local bg = cc.Sprite:create( "res/Main/hero/hero_item"..color..".png" )
                bg:setPosition( cellWidth/2, cellHeight/2 )
                bg:setScale( 0.75 )
                cellBg:addChild( bg )
                local sp = cc.Sprite:create( "res/Main/drillField/drillField_head_sock.png" )
                sp:setPosition( cellWidth/2, cellHeight/2 )
                cellBg:addChild( sp )
                local text = zc.lang("tips_unopen_fornow")
                if self._openData[index] then
                    text = zc.lang("drillField") .. self._openData[index].level .. zc.lang("level_1")
                end
                local label = zc.createLabel({
                    text = text,
                    fontSize = 20,
                    pos = cc.p(cellWidth/2, 17),
                    outLine = true,
                })
                cellBg:addChild( label )
            end
            -- btn
            local btn = ccui.Widget:create()
            btn:setContentSize( cellWidth, cellHeight )
            btn:setPosition( cellWidth/2, cellHeight/2 )
            btn:setTouchEnabled( true )
            btn:setSwallowTouches( false )
            cellBg:addChild( btn )
            btn:onTouch(function(event)
                if event.name == "began" then
                    cellBg:runAction(
                        cc.ScaleTo:create( 0.05, 0.9 )
                    )
                elseif event.name == "moved" then
                elseif event.name == "ended" then
                    cellBg:runAction(
                        cc.ScaleTo:create( 0.05, 1 )
                    )
                    if endCallback then
                        endCallback()
                    end
                elseif event.name == "cancelled" then
                    cellBg:runAction(
                        cc.ScaleTo:create( 0.05, 1 )
                    )
                end
            end)
            ---功能引导
            if data then
                if index == 1 and tonumber( data.status ) == 0 then
                    self._guideBtn = btn
                elseif index == 1 and tonumber( data.status ) == 1 then
                    self._guideBtn_1 = btn
                end
            end
        end, function() end)
        

        return cell
    end
    local function numberOfCellsInTableView()
        return 8
    end
    listTableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    listTableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    listTableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    listTableview:reloadData()
end
-- 训练位信息
function DrillFieldLayer:initListInfo()
	-- bg
	local bg = cc.Sprite:create( "res/Main/drillField/drillField_time_bg.png" )
	bg:setAnchorPoint( 1, 0.5 )
	bg:setPosition( self._size.width, self._size.height - 120 )
	self:addChild( bg, 30 )
	-- 训练位品质
	local qualityLabel = zc.createLabel({
        text = zc.lang("drill_pos_quality")..":",
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(50, 75),
        outLine = true,
    })
    bg:addChild( qualityLabel )
	local qualityDesc = zc.createLabel({
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(170, 75),
        outLine = true,
        color = display.COLOR_GREEN,
    })
    bg:addChild( qualityDesc )
    self._qualityDesc = qualityDesc
    -- 训练倒计时
    local timerLabel = zc.createLabel({
        text = zc.lang("drill_pos_time_count")..":",
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(50, 45),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( timerLabel )
    local timerDesc = zc.createLabel({
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(170, 45),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( timerDesc )
    self._timerDesc = timerDesc
    -- 武将经验值
    local expLabel = zc.createLabel({
        text = zc.lang("already1") .. zc.lang("get_exp") .. ":",
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(50, 15),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( expLabel )
    local expDesc = zc.createLabel({
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(170, 15),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( expDesc )
    self._expDesc = expDesc
end
-- 武将信息
function DrillFieldLayer:initHeroInfo()
	-- bg
	local bg = cc.Sprite:create( "res/Main/drillField/drillField_bottom_bg_s.png" )
	bg:setAnchorPoint( 0.5, 0 )
	bg:setPosition( self._size.width/2, 10 )
	self:addChild( bg )
	-- 当前等级
	local levelLabel = zc.createLabel({
        text = zc.lang("curr_level")..":",
        fontSize = 26,
        pos = cc.p(120, 40),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( levelLabel )
    local levelNum = zc.createLabel({
        -- text = "",
        fontSize = 26,
        ap = cc.p(0, 0.5),
        pos = cc.p(180, 40),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    bg:addChild( levelNum )
    self._levelNum = levelNum
    -- 进度条
    local expBg = cc.Sprite:create( "res/Main/drillField/drillField_heroExp_bg_1.png" )
    expBg:setAnchorPoint( 0, 0.5 )
    expBg:setPosition( 300, 40 )
    bg:addChild( expBg )
    self._expBg = expBg
    local expBar = cc.ProgressTimer:create( cc.Sprite:create( "res/Main/drillField/drillField_heroExp_1.png" ) )
    expBar:setType( cc.PROGRESS_TIMER_TYPE_BAR )
    expBar:setMidpoint( cc.p( 0, 0.5 ) )
    expBar:setBarChangeRate( cc.p( 1, 0 ) )
    expBar:setPosition( expBg:getContentSize().width/2, expBg:getContentSize().height/2 )
    expBg:addChild( expBar )
    self._expBar = expBar
    local expNum = zc.createLabel({
        fontSize = 20,
        pos = cc.p( expBg:getContentSize().width/2, expBg:getContentSize().height/2 ),
        outLine = true,
        -- color = display.COLOR_YELLOW,
    })
    expBg:addChild( expNum )
    self._expNum = expNum
    -- 终止按钮
    local stopBtn = zc.createCommomBtn({
        tag = 2,
        text = zc.lang("stop"),
        pos = cc.p(670, 40), 
        listener = function()
            local positionData = self._positionData[self._listIndex]
        	if positionData and positionData.hero and positionData.hero.id then
                local pop = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    msg = zc.lang("is_stop_train"),
                    rightCallback = function()
                        zc.sendHttp({
                            apiName = "Training_endTraining",
                            params = {
                                heroId=positionData.hero.id,
                                houseId = self._houseInfo.id
                            },
                            successCallback = function (data)
                                --刷新界面
                                self:stopTraining()
                                positionData.heroId = 0
                                positionData.endTime = 0
                                positionData.lastGetExpTime = 0
                                positionData.hero = {}
                                -- data.hero.beforeexp = data.hero.exp
                                -- data.hero.beforelevel = data.hero.level
                                -- PlayerData:updateGeneralInfo(data.hero)
                                -- 训练位列表
                                self._listTableview:reloadData()
                            end
                        })
                    end,
                    showDi = true,
                })
                self:addChild( pop, 50 )
		    end
        end,
    })
    stopBtn:setScale( 0.9 )
    bg:addChild( stopBtn )
    self._stopBtn = stopBtn
    -- 突飞猛进
    local upgradeBtn = zc.createPushButton({
        normalFile = "res/Main/drillField/drillField_upgrade.png",
        touchScale = 0.95,
        pos = cc.p(self._size.width-80, 80),
        needEnableWhenOut = true,
        beganCallback = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12712
              or _currentGID == GuideKey.KEY_12713
              or _currentGID == GuideKey.KEY_12714 then
                self._status = 5
                return
            end

            self._status = 0
            local positionData = self._positionData[self._listIndex]
            -- 判断训练武将
            do
                if not positionData or not positionData.hero or not positionData.hero.id then
                    zc.tipInfo( zc.lang("tips_please_select_hero") )
                    self._status = 1
                    return
                end
            end
            -- 判断能否转生
            local heroLevel = tonumber( positionData.hero.level ) or 0
            local heroRcnt = tonumber( positionData.hero.reincarnate ) or 0
            do
                local _flag = self:calculateRcnt( heroLevel, heroRcnt )
                if _flag then
                    -- 可以转生
                    self._status = 2
                    return
                end
            end
            -- 判断经验是否达到上限
            -- 最多可使用的突飞卡数量
            local maxNum, rcntFlag = self:calculateCardNum( positionData.hero.level, positionData.hero.reincarnate, positionData.hero.exp )
            do
                if maxNum <= 0 then
                    zc.tipInfo( zc.lang("tips_solider_level_reach_main_role_level") )
                    self._status = 3
                    return
                end
            end
            -- 判断突飞卡数量是否足够
            do
                if self._expCardNum <= 0 then
                    -- 创建突飞卡商店
                    self._status = 4
                    return
                end
            end
            -- 开始突飞
            do
                self._status = 5
                -- 按下按钮的起始时间
                self._upgradeTime = socket.gettime()
                -- 使用的突飞卡数量
                self._upgradeNum = 0
                -- 连续突飞的速度
                local _speed = 1
                -- 记录当前的转生和等级
                self._tmpAdvanced = positionData.hero.reincarnate
                self._tmpLevel = positionData.hero.level
                -- 开启计时器
                if self._upgradeTimer then
                    scheduler.unscheduleGlobal( self._upgradeTimer )
                    self._upgradeTimer = nil
                end
                -- 等级上限，true可以继续
                local levelUpFlag = true
                -- 数量上限，true可以继续
                local numEnoughFlag = true
                self._upgradeTimer = scheduler.scheduleGlobal(function()
                    if levelUpFlag and numEnoughFlag then
                        -- 突飞卡数量
                        self._upgradeNum = self._upgradeNum + self._upgradeConfig[_speed]
                        -- 伪造突飞卡使用
                        self._expCardData.num = self._expCardNum - self._upgradeNum
                        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_BASEINFOCHANGE})
                        -- 设置经验条
                        self:calculateExp( positionData.hero.level, positionData.hero.reincarnate, positionData.hero.exp )
                        -- 使用突飞卡特效
                        if self._hero and not self._hero._anm:isVisible() then
                            self._hero._anm:getAnimation():play( "shengjitexiao", -1, 1 )
                            self._hero._anm:setVisible( true )
                        end
                        -- 速度，提前计算下一次的速度，避免浪费一次间隔
                        _speed = _speed < #self._upgradeConfig and _speed + 1 or _speed
                        for i = _speed, 1, -1 do
                            local nextNum = self._upgradeNum + self._upgradeConfig[i]
                            -- print("数量    nextNum=",nextNum," maxNum=",maxNum," self._expCardNum=",self._expCardNum)
                            -- levelUpFlag
                            if nextNum <= maxNum then
                                levelUpFlag = true
                            else
                                levelUpFlag = false
                            end
                            -- numEnoughFlag
                            if nextNum <= self._expCardNum then
                                numEnoughFlag = true
                            else
                                numEnoughFlag = false
                            end
                            -- break
                            if levelUpFlag and numEnoughFlag then
                                _speed = i
                                break
                            end
                        end
                    else
                        self._hero._anm:setVisible( false )
                        if levelUpFlag then
                            zc.tipInfo( LANGUAGE_SHOP.shop_expCard .. LANGUAGE_ROLE.not_enough )
                            self:doGuideOver()
                        elseif numEnoughFlag then
                            if rcntFlag then
                                zc.tipInfo(zc.lang("qing_zhuansheng"))
                                self:doGuideOver()
                            else
                                self:doGuideOver()
                                zc.tipInfo( zc.lang("tips_solider_level_reach_main_role_level") )
                            end
                        end
                    end
                end, self._interval)
            end
        end,
        endCallback = function()
            if self._upgradeTimer then
                scheduler.unscheduleGlobal( self._upgradeTimer )
                self._upgradeTimer = nil
            end
            if self._hero then
                self._hero._anm:setVisible( false )
            end
            if self._status == 1 then

            elseif self._status == 2 then
                self:createHeroList( nil, self._positionData[self._listIndex].hero.id )
            elseif self._status == 3 then
            elseif self._status == 4 then
                local tipPop = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    msg = zc.lang("tips_tufei_not_enough_tobuy"),
                    showDi = true,
                    rightCallback = function()
                        -- 前往商店
                        zc.createExpCardShopLayer()
                    end
                })
                self:addChild( tipPop, 50 )
            elseif self._status == 5 then
                -- 使用突飞卡
                local useNum = 0
                -- 是否需要单独处理升级动画
                local _levelUp = false
                if self._upgradeTime and socket.gettime() - self._upgradeTime > self._interval then
                    -- 连续使用
                    useNum = self._upgradeNum
                else
                    -- 使用一次
                    useNum = 1
                    _levelUp = true
                end
                local positionData = self._positionData[self._listIndex]
                print("使用突飞卡====================",useNum)
                -- dump( positionData.hero, "positionData.hero" )
                -- 背包中的突飞卡数量恢复正常
                self._expCardData.num = self._expCardNum
                zc.sendHttp({
                    apiName = "Training_accelerate",
                    params = {
                        heroId = positionData.hero.id,
                        type = 1,
                        itemId = self._expCardData.id,
                        useNum = useNum
                    },
                    successCallback = function(data)
                        -- dump( data, "Training_accelerate" )
                        -- 修改突飞卡数量
                        local _currentGID = getGuideManager():getCurrentGID()
                        if _currentGID == GuideKey.KEY_12712
                          or _currentGID == GuideKey.KEY_12713
                          or _currentGID == GuideKey.KEY_12714 then
                            self:doClickGuide()
                        end
                        PlayerData:subPropFromBag(self._expCardData.id, useNum)
                        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_BASEINFOCHANGE})
                        self._expCardNum = zc.getBagNumByType( 1, 1001 )
                        -- 刷新界面
                        if _levelUp and self._hero then
                            self._hero._anm:getAnimation():play( "shengjitexiao", -1, 0 )
                            self._hero._anm:setVisible( true )
                        end
                        self:showAnimation( _levelUp, positionData.hero, data.hero, function()
                            self._listTableview:updateCellAtIndex( self._listIndex - 1 )
                            self:refreshHero()
                        end)
                        positionData.hero = data.hero
                        -- positionData.hero.beforeexp = positionData.hero.exp
                        -- positionData.hero.beforelevel = positionData.hero.level
                        PlayerData:updateGeneralInfo( data.hero )
                    end,
                    failCallback = function()
                        self:doGuideOver()
                        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_BASEINFOCHANGE})
                    end,
                    errorCallback = function()
                        self:doGuideOver()
                        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_BASEINFOCHANGE})
                    end
                })
            end
        end,
    })
    upgradeBtn:setTouchCancelledCallback(function()
        self._upgradeBtn:runAction(cc.ScaleTo:create(0.05, 1))
        if self._upgradeTimer then
            scheduler.unscheduleGlobal( self._upgradeTimer )
            self._upgradeTimer = nil
        end
        if self._expCardData then
            self._expCardData.num = self._expCardNum
        end
        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_BASEINFOCHANGE})
        self:refreshHero()
    end)
    self:addChild(upgradeBtn)
    self._upgradeBtn = upgradeBtn
    -- 长按可连续突飞
    local tipLabel = zc.createLabel({
        text = zc.lang("lang_press_to_tufei"),
        fontSize = 20,
        ap = cc.p(1, 0.5),
        pos = cc.p( self._size.width - 10, 15 ),
        outLine = true,
        color = display.COLOR_YELLOW,
    })
    self:addChild( tipLabel )
    self._tipLabel = tipLabel
end
-- 计算能否转生
function DrillFieldLayer:calculateRcnt( heroLevel, heroRcnt )
    -- 转生需求等级
    local _reincarnateLevel = self._advanceBeginLevel
    -- 转生数
    local _reincarnateNum = heroRcnt + 1
    local _data = gameData.getDataFromCache("hero_reincarnate", {level = _reincarnateNum,heroType = 1})
    if next(_data) ~= nil then 
        _reincarnateLevel = tonumber( _data.needLevel ) or 0
    end
    if heroLevel >= _reincarnateLevel then
        return true
    else
        return false
    end
end 
-- 计算武将升满级需要的突飞卡数量，或者到转生需要的突飞卡数量
function DrillFieldLayer:calculateCardNum( level, advanced, exp )
    -- 转生起始等级，50开始转生
    local advanceBeginLevel = self._advanceBeginLevel
    -- 转生等级，每5级转生一次
    local advanceLevel = self._advanceLevel
    -- 当前等级
    local oriLevel = tonumber( level ) or 0
    -- 当前转生数
    local oriAdvanced = tonumber( advanced ) or 0
    -- 主角等级
    local dstLevel = tonumber( PlayerData:getBaseInfo().level ) or 0
    -- 计算主角对应转生数，50级已经1转
    local dstAdvanced = 0
    if dstLevel >= advanceBeginLevel then
        dstAdvanced = math.ceil( ( dstLevel - advanceBeginLevel + 1 )/advanceLevel )
    end
    -- print(oriLevel,oriAdvanced,dstLevel,dstAdvanced)

    -- 计算总经验
    local totalExp = 0
    -- 经验值升满之后是否转生
    local flag = false
    if dstAdvanced > oriAdvanced then
        -- 需要转生，只计算到转生等级
        for i = oriLevel, advanceBeginLevel + oriAdvanced*advanceLevel - 1 do
            local _value = tonumber(gameData.getDataFromCacheWithPrimaryKey("hero_level", i).exp)
            totalExp = totalExp + _value
        end
        totalExp = totalExp + 1
        flag = true
    else
        -- 不需要转生，可以升到跟主角相同的等级
        for i = oriLevel, dstLevel do
           local _value = tonumber(gameData.getDataFromCacheWithPrimaryKey("hero_level", i).exp)
            totalExp = totalExp + _value
        end
        flag = false
    end
    -- 减去玩家已有的经验
    totalExp = totalExp - ( tonumber( exp ) or 0 )

    -- 每张突飞卡的经验值
    local cardExpNum = self._cardExpNum
    -- 需要的突飞卡数量
    local needNum = math.ceil( totalExp/cardExpNum )
    
    return needNum, flag
end
-- 计算使用经验卡之后玩家的等级和对应经验，不会有转生变化
function DrillFieldLayer:calculateExp( level, advanced, exp )
    -- 转生起始等级
    local advanceBeginLevel = self._advanceBeginLevel
    -- 转生等级
    local advanceLevel = self._advanceLevel
    -- 每张突飞卡的经验值
    local cardExpNum = self._cardExpNum
    -- print("每张突飞卡的经验值========cardExpNum=",cardExpNum," self._upgradeNum =",self._upgradeNum)
    -- 转生
    local advancedNum = tonumber( advanced )
    -- 等级
    local levelNum = tonumber( level )
    -- 经验
    local expNum = self._upgradeNum*cardExpNum + ( tonumber( exp ) or 0 )
    while true do
        local _value = tonumber(gameData.getDataFromCacheWithPrimaryKey("hero_level", levelNum).exp) or 0
        local expTmpNum = expNum - _value
        if expTmpNum > 0 then
            -- 可以继续升级
            expNum = expTmpNum
            levelNum = levelNum + 1
        else
            -- 已升至最高级
            break
        end
    end
    -- print("参数=======advancedNum=",advancedNum," levelNum=",levelNum," expNum=",expNum," self._tmpLevel=",self._tmpLevel," self._tmpAdvanced=",self._tmpAdvanced)
    -- 升的级数，不会有转生
    local levelDif = levelNum - self._tmpLevel
    -- print("----levelDif=",levelDif)
    local interval = self._interval/( levelDif + 1 )
    -- 主角等级
    local dstLevel = tonumber( PlayerData:getBaseInfo().level ) or 0
    -- 动作数组
    local array = {}
    local beginAdvanced = self._tmpAdvanced
    local beginLevel = self._tmpLevel
    for i = 1, levelDif do
        local level = beginLevel + i
        local advance = beginAdvanced
        array[#array + 1] = cc.ProgressTo:create( interval, 100 )
        if level <= dstLevel then
            array[#array + 1] = cc.ProgressTo:create( 0, 0 )
            array[#array + 1] = cc.CallFunc:create(
                function()
                    self._levelNum:setText( advance .. zc.lang("turn") .. level .. zc.lang("level_1") )
                    self:showLevelUp()
                end
            )
        else
            array[#array + 1] = cc.CallFunc:create(
                function()
                    local _value = tonumber(gameData.getDataFromCacheWithPrimaryKey("hero_level", dstLevel).exp)
                    self._expNum:setText( _value.."/".._value )
                end
            )
        end
    end
    -- 经验溢出的时候，溢出部分不要了
    if levelNum <= dstLevel then
        local _value = tonumber(gameData.getDataFromCacheWithPrimaryKey("hero_level", levelNum).exp)
        array[#array + 1] = cc.ProgressTo:create( interval, expNum/_value*100 )
        array[#array + 1] = cc.CallFunc:create(
            function()
                self._levelNum:setText( advancedNum .. zc.lang("turn") .. levelNum .. zc.lang("level_1"))
                self._expNum:setText( expNum .. "/" .. _value )
            end
        )
    end
    self._expBar:stopAllActions()
    self._expBar:runAction(
        cc.Sequence:create( array )
    )
    -- 记录本次升级到的进阶和等级
    self._tmpAdvanced = advancedNum
    self._tmpLevel = levelNum
end
-- 挑战
function DrillFieldLayer:starFight( npc, positionId )
	local data = gameData.getDataFromCacheWithPrimaryKey("training_npcGroup", npc)
	local enemyData = {}
	enemyData.enemys = {}
	for i = 1, 9 do 
    	local enemyId = tonumber(data["location"..i])
    	if enemyId ~= 0 then
    		enemyData["enemys"][i] = gameData.getDataFromCacheWithPrimaryKey("training_npc", enemyId)
    	else
    		enemyData["enemys"][i] = {}
    	end
    end
    local dataInfo = {
        battleType = BattleType.DrillField,
        enemys = enemyData,
        positionId = positionId,
        fightScene = 6,
    }
    self._refresh = true
    self._heroLayer:removeAllChildren()
    self._hero = nil
    zc.createMatrixBattle( dataInfo )
end
-- 创建武将列表弹窗
function DrillFieldLayer:createHeroList( index, heroId )
	-- 组织数据
    local heroListData = {}
    local mainRoleId = tonumber( PlayerData.info.heroId )
    for i, v in ipairs( PlayerData:getGeneralInfo() ) do
        if tonumber( v.status ) == 1 and tonumber( v.id ) ~= mainRoleId then
            heroListData[#heroListData + 1] = v
        end
    end
    if #heroListData > 0 then
        local heroListPop = requires("src/layer/drillField/DrillFieldHeroListLayer.lua" ):create({
            houseInfo = self._houseInfo.id,
            typeData = self._typeData,
            positionData = self._positionData,
            position = index,
            heroId = heroId,
            beginDrillFun = function( data )
                -- dump(data)
                -- 经验结算
                data.trainExp = 0
                self._positionData[index] = data
                self._listIndex = index
                self._listTableview:updateCellAtIndex( self._listIndex - 1 )
                self:createHero()

                ---功能引导
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_12712
                  or _currentGID == GuideKey.KEY_12713
                  or _currentGID == GuideKey.KEY_12714 then
                    getGuideManager():setObjTarget(self._upgradeBtn)
                    getGuideManager():startGuide()
                end
            end,
            rcntFunc = function( data )
                self._positionData[self._listIndex].hero = data
                self._listTableview:updateCellAtIndex( self._listIndex - 1 )
                self:refreshHero()
            end
        })
        if heroListPop._exist then
            LayerManager.addNode(heroListPop,{layerName = "DrillFieldHeroListLayer"})
        else
            zc.tipInfo(zc.lang("tips_go_to_soldier_view"))
        end
    else
        zc.tipInfo(zc.lang("tips_go_to_soldier_view"))
    end
end

-- 创建英雄
function DrillFieldLayer:createHero()
    -- 英雄动画
    local id = nil
    if self._positionData[self._listIndex] and self._positionData[self._listIndex].hero then
        id = self._positionData[self._listIndex].hero.id
    end
    local _heroData = PlayerData:getGeneralInfoById( id )
    if not id or not _heroData then
        return
    end
    self._heroLayer:removeAllChildren()
    self._hero = nil
    local heroId = _heroData.heroId
	local modelId = gameData.getDataFromCacheWithPrimaryKey("hero", heroId).modelId
    local weaponId = ( PlayerData:getWeaponsInfoById( id ) or {} ).weaponId
    -- 加载资源
    ccs.ArmatureDataManager:getInstance():addArmatureFileInfo( "res/image/battle/hero/"..tostring( modelId )..".csb" )
    self._record[tostring( modelId )] = true
	local hero = BattleHero:createWithParams({
		isDemo = true ,
        demoTargets = self._enemy,
        heroDataModelId = modelId,
        heroData = {
	        100000,
	        0,
	        5,   --位置
	        1,
	        modelId,
	        53,
	        7160,
	        7160,
	        0,
	        10,
	        10,
	        modelId,
	        weaponId,
        }
    })
    self._heroLayer:addChild( hero )
    self._hero = hero
    local _key = 1
    hero:doSkill({
        skillType = _key,
        firstTarget = self._firstTargetEnemy,
    })
    _key = 2
    hero:getArmature():getAnimation():setMovementEventCallFunc(function(armature, movementType, movementID)
        if 1 == tonumber(movementType) then
            hero:getArmature():getAnimation():play("idle")
            local function _callBack()
                hero:doSkill({skillType = _key , firstTarget = self._firstTargetEnemy})
                _key = _key%3 + 1
            end
            performWithDelay(hero,_callBack,2.0)
        end
    end)
    -- 使用突飞卡的特效
    local levelUpAnm = zc.createArmature({
        parentPath = "res/animation/shengjitexiao/",
        fileName = "shengjitexiao",
        actName = "shengjitexiao",
        eventCallback = function() end,
    })
    levelUpAnm:setPosition( self._hero:getSlotPositionInNode(BATTLE_BONE_NAME.MID, self._hero) )
    levelUpAnm:setVisible( false )
    self._hero:addChild( levelUpAnm )
    self._hero._anm = levelUpAnm
    levelUpAnm:getAnimation():setMovementEventCallFunc(function (armatureBack,movementType,movementID)
        if movementType == ccs.MovementEventType.complete then
            if self._hero then
                self._hero._anm:setVisible( false )
            end
        end
    end)
    for i, v in ipairs( self._enemy ) do
        v:setPosition( v:getInitialPoint() ) 
    end
    self:refreshHero()
end
function DrillFieldLayer:refreshHero()
    local _data = self._positionData[self._listIndex]
    -- 刷新训练位信息
    self._qualityDesc:setText( ( 100*( self._expAddData[self._listIndex] or 1 ) ).."%"..zc.lang("common") )
    self._expDesc:setText( _data.trainExp )
    -- 开始倒计时
    local time = tonumber( _data.endTime ) - tonumber( PlayerData:getTime() )
    if time > 0 then
        self:startTimer( time )
    end
    -- 刷新武将信息
    local exp = _data.hero.exp
    local expLimit = _data.hero.expLimit
    -- print("------------刷新武将信息        ",_data.hero.reincarnate.."转".._data.hero.level.."级")
    self._levelNum:setText( _data.hero.reincarnate .. zc.lang("turn") .. _data.hero.level .. zc.lang("level_1") )
    self._expBar:stopAllActions()
    self._expBar:setPercentage( exp/expLimit*100 )
    self._expNum:setText( exp.."/"..expLimit )
    self._stopBtn:setVisible( true )
    -- 刷新转生按钮
    self:refreshRcnt()
end

-- 创建敌人
function DrillFieldLayer:createEnemy()
	local enemy = BattleHero:createWithParams({
		isDemo = true,
		heroData = {
			100000,
			1,
			2,
			1,
			self._enemyData.image,
			53,
			7160,
			7160,
			0,
			10,
			10,
			self._enemyData.image,
			"",
        }
    })
    self._enemyLayer:addChild( enemy )
    self._enemy = {}
    self._enemy[#self._enemy + 1] = enemy
    self._firstTargetEnemy = enemy
end

-- 倒计时相关
function DrillFieldLayer:startTimer( time )
    self:stopTimer()
    self:tick( time )
    self._timer = scheduler.scheduleGlobal(function()
        time = time - 1
        self:tick( time )
    end, 1)
end
function DrillFieldLayer:tick( time )
    if time <= 0 then
        -- 倒计时结束
        self:stopTraining()
        -- 训练位数据
        self:refreshData()
    else
        -- 倒计时
        self._timerDesc:setText( zc.timeToClock( time, false ) )
    end
end
function DrillFieldLayer:stopTimer()
    if self._timer then
        scheduler.unscheduleGlobal( self._timer )
        self._timer = nil
    end
end

-- 训练停止
function DrillFieldLayer:stopTraining()
    -- 武将动画
    self._heroLayer:removeAllChildren()
    self._hero = nil
    -- 训练位信息
    self._qualityDesc:setText( "" )
    self._timerDesc:setText( "" )
    self._expDesc:setText( "" )
    self:stopTimer()
    -- 武将信息
    self._levelNum:setText( "" )
    self._expBar:setPercentage( 0 )
    self._expNum:setText( "" )
    self._stopBtn:setVisible( false )
    -- 经验结算
    self:expSettlement()
end
-- 单人经验结算
function DrillFieldLayer:expSettlement()
    local _data = self._positionData[self._listIndex]
    local startTime = tonumber( _data.startTime )
    local endTime = tonumber( _data.endTime )
    local difTime = 0
    if endTime > startTime then
        difTime = tonumber(PlayerData:getTime()) - startTime
    else
        difTime = endTime - startTime
    end
    local params = {
        heroData = self._positionData[self._listIndex].hero,
        expAddData = self._expAddData[self._listIndex],
        time = difTime,
        addExp = _data.trainExp,
    }
    if params.heroData and params.heroData.level then
        -- 奇怪的bug，暂时处理
        zc.createSourcePop( "DrillFieldExpSettlementPop", "src/layer/drillField/DrillFieldExpSettlementPop.lua", params )
    end
end
-- 重新请求数据
function DrillFieldLayer:refreshData()
    local houseData = PlayerData:getHouseInfoByHouseId(8)
    zc.sendHttp({
        apiName = "Training_main",
        params = { houseId = houseData.id },
        successCallback = function (data)
            -- dump( data, "Training_main" )
            self._typeData = data.types
            self._positionData = data.positions
            -- 排序位置数据
            table.sort(self._positionData, function( a, b )
                return tonumber( a.position ) < tonumber( b.position )
            end)

            -- 经验结算
            local _tss = tonumber( PlayerData:getTssTime() ) or 0
            for i, v in ipairs( self._positionData ) do
                if v.expYield and v.startTime then
                    v.trainExp = tonumber( v.expYield )*( _tss - tonumber( v.startTime ) )
                    v.trainExp = math.floor( v.trainExp )
                else
                    v.trainExp = 0
                end
            end

            self._listTableview:reloadData()
            self:createHero()
            self:trainingOver()
            --功能引导

            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12710 then
                getGuideManager():addMaskLayer()
                performWithDelay(self, function()
                    getGuideManager():removeMaskLayer()
                    getGuideManager():setObjTarget(self._guideBtn_1)
                    getGuideManager():startGuide()
                end, 0.3)
            end
        end
    })
end
-- 训练结束界面
function DrillFieldLayer:trainingOver()
    -- dump( self._positionData )
    -- hero为空表示训练位没人训练或者训练已结束,heroId为上次训练的武将id
    -- hero = {} and heroId ~= 0表示武将训练结束
    local heroData = {}
    for i, v in ipairs( self._positionData ) do
        if ( not v.hero or table.nums( v.hero ) == 0 ) and tonumber( v.heroId ) ~= 0 and tonumber( v.addExp ) ~= 0 then
            local data = PlayerData:getGeneralInfoById( v.heroId )
            heroData[#heroData + 1] = {
                data = data,
                addExp = v.addExp,
            }
        end
    end
    if #heroData > 0 then
        zc.createSourcePop( "DrillFieldTrainingOverPop", "src/layer/drillField/DrillFieldTrainingOverPop.lua", {heroData = heroData} )
    end
end

-- 修改转生按钮状态
function DrillFieldLayer:refreshRcnt()
    -- 判断能否转生
    local positionData = self._positionData[self._listIndex]
    if not positionData or not positionData.hero or not positionData.hero.id then
        return
    end
    local heroLevel = tonumber( positionData.hero.level ) or 0
    local heroRcnt = tonumber( positionData.hero.reincarnate ) or 0
    local _flag = self:calculateRcnt( heroLevel, heroRcnt )
    if _flag then
        self._upgradeBtn:getStateNormal():setTexture("res/Main/drillField/drillField_rcnt.png")
        self._tipLabel:setVisible( false )
    else
        self._upgradeBtn:getStateNormal():setTexture("res/Main/drillField/drillField_upgrade.png")
        self._tipLabel:setVisible( true )
    end
end

-- 使用突飞卡之后的动画
function DrillFieldLayer:showAnimation( single, oriData, newData, callback )
    if single then
        -- 升的级数，不会有转生
        local _oriAdvance = tonumber( oriData.reincarnate ) or 0
        local _oriLevel = tonumber( oriData.level ) or 0
        local _newAdvance = tonumber( newData.reincarnate ) or 0
        local _newLevel = tonumber( newData.level ) or 0
        local _newExp = tonumber( newData.exp ) or 0
        local _newExpLimit = tonumber( newData.expLimit ) or 0

        local _difLevel = _newLevel - _oriLevel
        local _interval = 0.2/( _difLevel + 1 )
        -- 动作数组
        local array = {}
        for i = 1, _difLevel do
            array[#array + 1] = cc.ProgressTo:create( _interval, 100 )
            local level = _oriLevel + i
            array[#array + 1] = cc.ProgressTo:create( 0, 0 )
            array[#array + 1] = cc.CallFunc:create(
                function()
                    self._levelNum:setText( _oriAdvance .. zc.lang("turn") .. level .. zc.lang("level_1") )
                    self:showLevelUp()
                end
            )
        end
        -- 经验溢出的时候，溢出部分不要了
        array[#array + 1] = cc.ProgressTo:create( _interval, _newExp/_newExpLimit*100 )
        array[#array + 1] = cc.CallFunc:create(
            function()
                self._levelNum:setText( _oriAdvance ..  zc.lang("turn") .. _newLevel .. zc.lang("level_1") )
                self._expNum:setText( _newExp .. "/" .. _newExpLimit )
            end
        )
        array[#array + 1] = cc.CallFunc:create(function()
            if callback then
                callback()
            end
        end)
        self._expBar:stopAllActions()
        self._expBar:runAction(
            cc.Sequence:create( array )
        )
    else
        self._expBar:stopAllActions()
        self._expBar:runAction(
            cc.Sequence:create(
                cc.DelayTime:create( 0.2 ),
                cc.CallFunc:create(function()
                    if callback then
                        callback()
                    end
                end)
            )
        )
    end
end

--新手引导
function DrillFieldLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if inArray(_currentGID, GuideGroup.DUI_HUA) then
        local function _callBack()
            getGuideManager():addMaskLayer()
            performWithDelay(self, function()
                getGuideManager():removeMaskLayer()
                if self._guideBtn then
                    getGuideManager():setObjTarget(self._guideBtn)
                    getGuideManager():startGuide()
                elseif self._guideBtn_1 then
                    getGuideManager():setCurrentGID(GuideKey.KEY_12710)
                    getGuideManager():setObjTarget(self._guideBtn_1)
                    getGuideManager():startGuide()
                else
                    self:doGuideOver()
                end
            end, 0.15)
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
   end
end

function DrillFieldLayer:doClickGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12712 or _currentGID == GuideKey.KEY_12713 then
        zc.setGuideFuncNextStep(_currentGID)
        getGuideManager():setObjTarget(self._upgradeBtn)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_12714 then
        self:doGuideOver()
    end
end
function DrillFieldLayer:doGuideOver()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12712
      or _currentGID == GuideKey.KEY_12713
      or _currentGID == GuideKey.KEY_12714 then
        zc.setGuideFuncNextStep(GuideKey.KEY_12714)
        getGuideManager():setHeroFuncCallBack(function()
            local _guideHand = zc.createSpine({
                fileName = "shou",
                actName = "shou",
                scale = 0.6
            })
            _guideHand:setPosition(cc.pMul(cc.pFromSize(self._backBtn:getContentSize()), 0.5))
            self._backBtn:addChild(_guideHand)
            performWithDelay(_guideHand, function()
                _guideHand:removeFromParent()
                _guideHand = nil
            end, 4)
            local _mainCity = zc.getScene("mainCity")
            if _mainCity then
                _mainCity:setFubenHandFlag()
            end
        end)
        getGuideManager():startGuide()
    end
end

-- 升级动画
function DrillFieldLayer:showLevelUp()
    if self._expBg then
        if self._lvUpArm and not tolua.isnull( self._lvUpArm ) then
            self._lvUpArm:removeFromParent()
            self._lvUpArm = nil
        end
        local _lvUpArm = zc.createSpine({
            fileName = "jiaochangjingyan",
            autoRemove = true,
            loop = false,
            actName = "animation",
            needInit = false,
        })
        _lvUpArm:setPosition( self._expBg:getContentSize().width/2 - 1, self._expBg:getContentSize().height/2 + 4 )
        self._expBg:addChild( _lvUpArm )
        self._lvUpArm = _lvUpArm
        musicManager.playEffect( zc.effect.levelUp )
    end
end

return DrillFieldLayer