local ShowRewardPop = class("ShowRewardPop",function ()
	return ZCPopLayer:create()
end)

function ShowRewardPop:ctor(params)
	musicManager.playEffect( zc.effect.btnFetch )
    self:setOpacity(200)
	self:initData(params)
	self:initUI()

	local _callBack = params.callback
	self:setHideCallback(function()
		if _callBack and type(_callBack) == "function" then
			_callBack()
		end
	end)
	self:show()
end

function ShowRewardPop:initData(params)
	--特殊处理(转盘，显示获得倍数)
	if params.__TurnInfo then
		self.__TurnInfo = params.__TurnInfo
	end
	local _overTypeMap = params.overTypeMap

	self._allClientItems = params.clientItems
	self._usedWeaponIndex = {}
	local _colorToQuality = {[1]=1,[2]=2,[3]=3,[4]=5,[5]=8,[6]=10} --颜色对应的品级，只是图片对应，没其它的意义
    local showGet = PlayerData:getShowIconDatas(params)

    local totalReward = {}
    local rewardMap = {}
    for i = 1, table.nums(showGet) do
		local v = showGet[i]
		local itemType = tonumber(v["itemType"])
		local itemId = tonumber(v["itemId"])
		local _donext = true
		if itemType and itemType > 0 and itemId and itemId > 0 then
			if itemType == 1 and itemId == 12 then --过滤不需要显示的物品（名将册体力）
				_donext = false
			end
		else
			_donext = false
		end
		if v.currentNum and tonumber(v.currentNum) == 0 then
			_donext = false
		end
		if _donext then
			if not rewardMap[itemType] then
				rewardMap[itemType] = {}
			end
			local typeMap = rewardMap[itemType]
			if _overTypeMap or (itemType ~= 1 and 
				itemType ~= 4 and 
				itemType ~= 6 and 
				itemType ~= 2) then --个数需要累加的：物资、背包物品、武将(本来是不累加的，扫荡的特殊处理)、玩家经验；个数不累加的现在只有武器、饰品
				typeMap = {}
			end
			if typeMap[itemId] then
				local idx = typeMap[itemId]
				if itemType == 2 then
					totalReward[idx].changeNum = 1
				else
					totalReward[idx].changeNum = tonumber(totalReward[idx].changeNum) + tonumber(v["changeNum"])
				end
			else
				local idx = #totalReward + 1
				typeMap[itemId] = idx
				totalReward[idx] = v
				
				--设置权重排序
				local _quality = 0 
				if itemType == zc.mainTypeResource then--资源
					_quality = 3
			        if itemId == zc.dataTypeTopaz then
			            _quality = _colorToQuality[4]
			        elseif itemId == zc.dataTypeAmethyst
			          or itemId == zc.dataTypeEnergy
			          or itemId == zc.dataTypeTax then
			            _quality = _colorToQuality[5]
			        end
				elseif itemType == zc.mainTypeSoldier then--武将
        			local itemData = gameData.getDataFromCacheWithPrimaryKey("hero", itemId) or {}
					_quality = tonumber(itemData.qualifications)
				elseif itemType == zc.mainTypeWeapon then--兵器
        			local weaponData = gameData.getDataFromCacheWithPrimaryKey("weapon", itemId) or {}
					_quality = tonumber(weaponData.quality)
				elseif itemType == zc.mainTypeProp then--道具
        			local itemData = gameData.getDataFromCacheWithPrimaryKey("item", itemId) or {}
        			if tonumber(itemData.quality) == 0 then
						_quality = tonumber(_colorToQuality[tonumber(itemData.color)]) or 0
        			else
						_quality = tonumber(itemData.quality)
					end
				elseif itemType == zc.mainTypeSoldierExp then--武将经验
					_quality = 3
				elseif itemType == zc.mainTypePlayerExp then--玩家经验
					_quality = 3
				elseif itemType == zc.mainTypeSarmsChip then--升星材料碎片
				elseif itemType == zc.mainTypeSoldierCard then--武将卡
				elseif itemType == zc.mainTypeTrinket then--饰品
        			local itemData = gameData.getDataFromCacheWithPrimaryKey("trinket", itemId) or {}
					_quality = tonumber(_colorToQuality[tonumber(itemData.color)]) or 0
				elseif itemType == zc.mainTypeSarms then--升星材料
				elseif itemType == zc.mainTypeEquip then--装备
				elseif itemType == zc.mainTypeGem  then--宝石
					local gemData = gameData.getDataFromCacheWithPrimaryKey("gem", itemId) or {}
					_quality = tonumber(gemData.quality)
				end
				if not _quality then _quality = 0 end
				totalReward[idx]._quality = _quality
			end
		end
    end
    table.sort(totalReward,function(a,b)
    	if a._quality ~= b._quality then
    		return a._quality > b._quality
    	else
    		return tonumber(a.itemId) < tonumber(b.itemId)
    	end
    end)
	self._reward = totalReward
end
function ShowRewardPop:findWeapon(_itemId)
	for i = 1, #self._allClientItems do
		local v = self._allClientItems[i]
		if v and tonumber(v.type) == 3 then
			if tonumber(v.itemId) == tonumber(_itemId) then
				if not self._usedWeaponIndex[i] then
					if v.model then
						self._usedWeaponIndex[i] = 1
						return self:getNowWeaponLevel(v.model)
					end
				end
			end
		end
	end
	return "0"
end
--因为数据还没更新所以用这里单独计算武器升级
function ShowRewardPop:getNowWeaponLevel(weaponData)
    -- 非主角兵器
    local levelTotal = 0
    local levelNum = 0
    for i = 1, 6 do
        if weaponData["effectId"..i] and weaponData["effectValue"..i] and weaponData["effectInfo"..i] and weaponData["effectInfo"..i]["valueLimit"] then
            local min = tonumber( weaponData["effectInfo"..i]["valueMin"] ) or 0
            local max = tonumber( weaponData["effectInfo"..i]["valueLimit"] ) or 0
            local cur = tonumber( weaponData["effectValue"..i] ) or 0
            levelTotal = levelTotal + math.ceil( ( cur - min )/( ( max - min )/100 ) )
            levelNum = levelNum + 1
        end
    end
    -- print("levelTotal = ", levelTotal, " levelNum = ", levelNum )
    if levelNum == 0 then
        return 0
    else
        local level = math.floor( levelTotal/levelNum )
        if level < 1 then
            level = 1
        elseif level > 100 then
            level = 100
        end
        return level
    end
end
function ShowRewardPop:initUI()
	-- 背景
	local background = cc.Sprite:create( "res/Main/battle/battleresult/battle_bg.png" )
	background:setPosition( zc.width/2, zc.height/2 - 30 )
	self:addContent( background )
	self._bg = background
	self._bgSize = background:getContentSize()
    local close = zc.createPushButton({
        touchSize = cc.size(10000,10000),
        needSwallow = true,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(self._bgSize.width/2, self._bgSize.height/2),
        endCallback = function() end,
    })
    background:addChild(close)
    self:runAction(cc.Sequence:create(
        cc.DelayTime:create(0.8),
        cc.CallFunc:create(function() close:setTouchEndedCallback(function() self:hide() end) end)
    ))
	-- 奖励
    local armature = zc.createArmature({
        parentPath = "res/Main/battle/battleresult/win/",
        fileName = "win",
        actName = "SWL_star_3",
        eventCallback = function() end,
        completeCallback = function(armatureBack,movementType,movementID)
            self._armature:getAnimation():play("SWL_idle_3", -1, 0)
        end
    })
    armature:setPosition(self._bgSize.width/2, self._bgSize.height)
    background:addChild(armature)
    self._armature = armature

	local closeLabel = zc.createLabel({
	    text = zc.lang("tips_click_empty_continue"),
	    outLine = true,
	    fontSize = 22,
	    ap = cc.p(0.5, 0),
	    pos = cc.p(self._bgSize.width/2, -25),
	    pixel = 1.3
	})
	background:addChild(closeLabel)
	closeLabel:setCascadeOpacityEnabled(true)
    closeLabel:setOpacity(255)
	closeLabel:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeIn:create(1),cc.FadeOut:create(1))))

    local bg = background
    local rewardNum = table.nums(reward)
    local distance = 135
    local itemsOfLine = 3
    local innerHeight = 256
    local reward = self._reward
	local skillPos = zc.sortFromMiddle(cc.p(self._bgSize.width/2, 170), #reward, distance)

	self:createRewardTablview(reward)
end
function ShowRewardPop:createRewardTablview(reward)
	local tableWidth = 135 * (#reward)
	if #reward > 6 then
		tableWidth = 135 * 6
	end

	local tableHeight = 120
	local cellWidth = 810
	local cellHeight = 116
	if self.__TurnInfo then
		tableHeight = 200
		cellHeight = 196
	end
	local _flag = false
	local _cellNum = math.ceil( #reward/6 )
	if _cellNum > 2 then
		tableHeight = tableHeight*2.6
		_flag = true
	else
		tableHeight = tableHeight*_cellNum
	end

	local tableSize = cc.size(tableWidth, tableHeight)
	local tableNode = self._bg

	local myTableBg = zc.getScaleNode("res/Main/common/img_empty.png", tableSize)
    local touchBtn = zc.createPushButton({
    	normalNode = myTableBg,
    	needSwallow = true,
    	pos = cc.p(tableNode:getContentSize().width/2, 170)
    })
    tableNode:addChild(touchBtn)
	
	local myTable = zc.ZCTableView:create(cc.size(myTableBg:getContentSize().width,myTableBg:getContentSize().height-4))
	myTable:setPosition(2,2)
	if _flag then
		myTable:setInertia(true) --设置惯性
		myTable:setBounceable(true)
	else
		myTable:setInertia(false) --设置惯性
		myTable:setBounceable(false)
	end
	myTable:setSwallowsTouches( true )
	myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
	myTable:setDelegate()
	myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
	
	myTableBg:addChild(myTable)
	
	local function cellSizeForTable(table,idx)
		return cellHeight, cellWidth
	end
	local function numberOfCellsInTableView(table)
	    return math.ceil( #reward/6 )
	end
	local function tableCellAtIndex(table,idx)
		local cell = table:dequeueCell()
	    if cell == nil then
	        cell = zc.ZCTableViewCell:new()
	        self:buildCell(cell, idx, cellWidth, cellHeight)
	    end
	    self:updateCell(cell, idx)

	    return cell
	end
	myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
	myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
	myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
	
	myTable:reloadData()
	self._isinit = true
end
function ShowRewardPop:buildCell(cell, idx, cellWidth, cellHeight)
	cell._item = {}
	for i = 1, 6 do
	    local posX = cellWidth/12*(2*i - 1)
	    local posY = cellHeight/2
		local item = zc.createIconByData({
	        data = {
	            mainType = 1,
	            type = 1, 
	            id = 1,
	            num = 0,
	        }, 
	        showDetailPop = true,
	        pos = cc.p(posX, posY),
	    })
	    cell:addChild(item)
	    local _desc = zc.createLabel({
	        outLine = true,
	        fontSize = 24,
	        pos = cc.p(item:getContentSize().width/2, item:getContentSize().height/2 - 80),
	        pixel = 1.3
	    })
	    item:addChild(_desc)
	    item._desc = _desc
	    item:setCascadeOpacityEnabled( true )
	    cell._item[i] = item
	end
end
function ShowRewardPop:updateCell(cell, idx)
	for i = 1, 6 do
		local _index = idx*6 + i
		local cellData = self._reward[_index]
		local item = cell._item[i]
		if not cellData then
			item:setVisible( false )
		else
			item:setVisible( true )
			local _itemType = tonumber(cellData.itemType) or 0
			local _itemId = tonumber(cellData.itemId) or 0

		    info = zc.updateIconByData(item, {
		        data = {
		            mainType = cellData.itemType,
		            type = cellData.itemId, 
		            id = cellData.itemId,
		            num = cellData.changeNum,
		            level = (_itemType == zc.mainTypeWeapon) and zc.getLevelTipShow()..self:findWeapon(_itemId) or nil
		        }, 
		        showLevel = (_itemType == zc.mainTypeWeapon) and true or false,
		        showDetailPop = true,
		    })

		    --如果是转盘，则显示获得的倍数
		    if self.__TurnInfo then
		    	local multiple = self.__TurnInfo.multiple or 1
		    	local _str = multiple.. zc.lang("beijiangli")
		    	item._desc:setString(_str)
		    	item._desc:setColor(display.COLOR_GOLD)
		    end

		    if not self._isinit then
			    item:setScale(1.0)
			    item:setOpacity(0)

				item:runAction(
					cc.Sequence:create(
						cc.DelayTime:create( 0.1*_index ),
						cc.Spawn:create(
							cc.FadeIn:create( 0.2 ),
							cc.Sequence:create(
								cc.DelayTime:create(0.1),
								cc.ScaleTo:create(0.15,0.8)
							)
						)
					)
				)
			else
				item:setScale(0.8)
			end
		end
	end
end

function ShowRewardPop:create(params,callback)
	local _hasItem = false --是否有要展示的物品
	if params.clientItems and next(params.clientItems) then
		_hasItem = true
	end
	if params.clientResources and next(params.clientResources) then
		_hasItem = true
	end
	if not _hasItem then
		return
	end
	return self.new(params)
end

function ShowRewardPop:onCleanup()
    local textureCache = cc.Director:getInstance():getTextureCache()
    textureCache:removeTextureForKey("res/plugin/ShowRewardPop/reward_bg.png")
    textureCache:removeTextureForKey("res/plugin/ShowRewardPop/reward_reel.png")
end


return ShowRewardPop