--[[
	名将副本关卡信息弹窗
	唐实聪
	2016.4.7
]]
local TollgateHeroEnemyPop = class("TollgateHeroEnemyPop",function ()
	return ZCPopLayer:create()
end)

function TollgateHeroEnemyPop:create( params )
    return TollgateHeroEnemyPop.new( params )
end

function TollgateHeroEnemyPop:ctor( params )
	self:initData( params )
	self:initUI()
    self:show()
end

function TollgateHeroEnemyPop:onEnter()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_11609 then
        getGuideManager():addMaskLayer()
        performWithDelay(self, function ()
            getGuideManager():removeMaskLayer()
            getGuideManager():setObjTarget(self._guideBtn)
            getGuideManager():startGuide()
        end, 0.3) 
    end            
end

function TollgateHeroEnemyPop:initData( params )
    self._info = params
    self._enemys = {}
    local enemys = gameData.getDataFromCache( "hero_npcGroup", {tollgateId = params.id})
    for i = 1, 9 do
    	self._enemys[i] = {}
    	if enemys["location"..i] and tonumber(enemys["location"..i]) and tonumber( enemys["location"..i] ) > 0 then
    		self._enemys[i] = gameData.getDataFromCacheWithPrimaryKey( "hero_npc", enemys["location"..i])
    	end
    end
    self._info.iconId = enemys.iconId

    -- 掉落数据
    self._dropData = {}
    local _tb = nil
    if self._info.first then
    	-- 首杀
        _tb = string.split( self._info.firstDrop, "," )
    elseif self._info.open then
    	-- 已打过
        _tb = string.split( self._info.commonDrop, "," )
    else
    	-- 未开启
        _tb = string.split( self._info.firstDrop, "," )
    end
    if _tb then
        for i, v in ipairs(_tb) do
            local data = gameData.getDataFromCacheWithPrimaryKey("drop_award", v)
            self._dropData[#self._dropData + 1] = data
        end
        self._dropData = zc.getActivity17AddInfo(2, self._dropData)
    end
    self._size = self:getContentSize()
end

function TollgateHeroEnemyPop:initUI()
	-- 背景
	local background = cc.Sprite:create( "res/Main/copy/copy_dibian.png" )
	background:setPosition( self._size.width/2, self._size.height/2 )
	self:addContent( background )
	self._bg = background
	self._bgSize = background:getContentSize()
    -- 关闭
	local close = zc.createBackButton({
		pos = cc.p( self._bgSize.width, self._bgSize.height ),
		listener = function ()
			self:hide()
		end
	})
	background:addChild( close, 1 )
    -- hero
    local heroPath = string.format( "res/Main/hero/body/%s.png", self._info.iconId )   
    if not zc.checkFileExist( heroPath )  then
        heroPath = "res/Main/hero/body/1.png"
    end
    local heroSp = cc.Sprite:create( heroPath )
    if not heroSp then
        heroSp = zc.createSprite( "res/Main/hero/body/1.png" )
    end
    heroSp:setAnchorPoint( 1, 1 )
    heroSp:setPosition( 480, self._bgSize.height )
    heroSp:setScale( 0.74 )
    -- stencil
    local stencil = cc.Node:create()
    stencil:setAnchorPoint( 0, 0 )
    stencil:setPosition( 0, 0 )
    local _stencil = cc.Sprite:create( "res/Main/copy/copy_dibian.png" )
    _stencil:setAnchorPoint( 0, 0 )
    _stencil:setPosition( 0, 3 )
    stencil:addChild( _stencil )
    -- clippingNode
    local clippingNode = cc.ClippingNode:create()
    clippingNode:addChild( heroSp )
    clippingNode:setStencil( stencil )
    clippingNode:setInverted( false )
    clippingNode:setAlphaThreshold( 1 )
    background:addChild( clippingNode )
    --标题
    local titlebg = cc.Sprite:create( "res/Main/tollgateHero/copy_title.png" )
    titlebg:setAnchorPoint( 0, 1 )
    titlebg:setPosition( 110, self._bgSize.height )
    background:addChild( titlebg )
    local nameFontSize = 26 
    if zc.utfstrlen( self._info.name ) > 4 then 
        nameFontSize = 22
    end
    local title = zc.createLabel({
        text = self._info.name,
        fontSize = nameFontSize,
        pos = cc.p( titlebg:getContentSize().width/2, titlebg:getContentSize().height/2 ),
        outLine = true,
        width = 26,
        color = display.COLOR_WHITE,
    })
    titlebg:addChild( title )
    --掉落
    local itemposx = 170
    local drop = cc.Sprite:create( "res/Main/copy/copy_title2.png" )
    drop:setPosition( self._bgSize.width/2 + itemposx, self._bgSize.height - 90 )
    background:addChild(drop)
    local dropTitleText = ""
    if self._info.first then
        dropTitleText = LANGUAGE_TOLLGATEHERO.first_drop
    elseif self._info.open then
        dropTitleText = LANGUAGE_TOLLGATEHERO.common_drop
    else
        dropTitleText = LANGUAGE_TOLLGATEHERO.first_drop
    end
    local droptitle = zc.createLabel({
        text = dropTitleText,
        fontSize = 20,
        pos = cc.p( drop:getContentSize().width/2, drop:getContentSize().height/2 ),
        outLine = true,
        color = display.COLOR_YELLOW,
    })
    drop:addChild( droptitle )
    
    local dropScrollView = zc.createScrollview({
        pos = cc.p( self._bgSize.width/2 + itemposx - 400/2, 175 ),
        size = cc.size( 400, 100 ),
        innerSize = cc.size( 90*#self._dropData, 100 ),
        dir = ccui.ScrollViewDir.horizontal,
        bar = false,
        bounceEnable = true,
    })
    background:addChild( dropScrollView )

    for i, v in ipairs( self._dropData )do 
        local iconColor = 1
        local goodName = ""
        if tonumber( v.itemType ) == zc.mainTypeSoldierExp then 
            -- 武将经验
            goodName = LANGUAGE_TOLLGATEHERO.general_exp
        elseif tonumber( v.itemType ) == zc.mainTypeProp then 
            -- 背包的道具
            local itemDb = PlayerData:getBagDBInfoByID( v["itemId"] )
            if itemDb then
                iconColor = tonumber( itemDb.color )
                goodName = itemDb.name
            end
        end
        local item = zc.createIconByData({
            data = {
                mainType = v.itemType,
                type = v.itemId, 
                id = v.itemId,
                num = v.itemNum,
            }, 
            showDetailPop = true,
            pos = cc.p( ( i - 0.5 )*90, 53 ), 
            color = iconColor
        })
        item:setScale( 0.68 )
        dropScrollView:addChild( item )
    end
    -- 消耗
    local costTitleBg = cc.Sprite:create( "res/Main/copy/copy_title2.png" )
    costTitleBg:setPosition( self._bgSize.width/2 + itemposx, 145 )
    background:addChild( costTitleBg )
    local costTitle = zc.createLabel({
        text = LANGUAGE_TOLLGATEHERO.copy_consume,
        fontSize = 20,
        pos = cc.p( costTitleBg:getContentSize().width/2, costTitleBg:getContentSize().height/2 ),
        outLine = true,
        color = display.COLOR_YELLOW,
    })
    costTitleBg:addChild( costTitle )
    -- 消耗物资
    local costBg = cc.Sprite:create( "res/Main/copy/copy_di.png" )
    costBg:setPosition( self._bgSize.width/2 + itemposx, 100 )
    background:addChild( costBg )
    local costLabel = zc.createLabel({
        text = LANGUAGE_TOLLGATEHERO.consume,
        fontSize = 20,
        pos = cc.p( 0, costBg:getContentSize().height/2 ),
        outLine = true,
        color = cc.c3b( 200, 100, 80 ),--display.COLOR_BROWN,
    })
    costBg:addChild( costLabel )
    local costIcon = cc.Sprite:create( "res/Main/common/common_icon_energy.png" )
    costIcon:setPosition( 50, costBg:getContentSize().height/2 )
    costBg:addChild( costIcon )
    local expendNum = tonumber( self._info.expend or 0 ) or 0
    local costNum = zc.createLabel({
        text = "x"..expendNum,
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 70, costBg:getContentSize().height/2 ),
        outLine = true,
        color = display.COLOR_WHITE,
    })
    costBg:addChild( costNum )

    --战斗按钮
    local battleBtn = zc.createCommomBtn({
        tag = 1,
    	pos = cc.p( self._bgSize.width/2 + itemposx, 40 ),
    	text = zc.lang("challenge_2"),
    	listener = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_11609 then
                getGuideManager():setFuncGuideOver()
            end
            if not self._info.challengable then
                -- 没有挑战次数
                zc.tipInfo( LANGUAGE_TOLLGATEHERO.no_challenge_times )
            elseif not self._info.energyEnable then
                -- 没有体力
                zc.tipInfo( zc.lang("tips_tili_unenough") )
            else
                -- 有挑战次数和体力
                if self._info.times and tonumber( self._info.times ) > 0 then
                    -- 每日只可挑战一次
                    zc.tipInfo( LANGUAGE_TOLLGATEHERO.challenge_once_one_day )
                else
                    local _first = self._info.first and 1 or 0
                    local _dataInfo = {
                        battleType= BattleType.TollgateHero,
                        enemys = {enemys = self._enemys},
                        topinfo = false,
                        tollgateId = self._info.id,
                        isFirstFight = _first,
                        chapterId = self._info.chapterId,
                    }
                    self:hide()
                    -- zc.createScene("matrixBattle", _dataInfo)
                    zc.createMatrixBattle( _dataInfo )
                end
            end
        end,
    })
    self._guideBtn = battleBtn
    background:addChild( battleBtn )
    if not self._info.open then
    	-- 未开启
    	battleBtn:setEnable( false )
        battleBtn:setString( LANGUAGE_TOLLGATEHERO.not_open )
    end
end

return TollgateHeroEnemyPop